@@ -1,11 +1,8 @@
 /*!
  * \file
- * \brief Definitions of special operations on vectors and matricies optimized 
+ * \brief Definitions of special operations on vectors and matricies optimized
  * for speed
  * \author Tony Ottosson and Tobias Ringstrom
- * 
- * $Date$
- * $Revision$
  *
  * -------------------------------------------------------------------------
  *
@@ -40,14 +37,14 @@
 
 namespace itpp {
 
-  /*! 
-    \relates Mat
+  /*!
+    \relatesalso Mat
     \brief Calculates m=m-v*v'*m
   */
   void sub_v_vT_m(mat &m, const vec &v);
 
-  /*! 
-    \relates Mat
+  /*!
+    \relatesalso Mat
     \brief Calculates m=m-m*v*v'
   */
   void sub_m_v_vT(mat &m, const vec &v);
