@@ -1,10 +1,8 @@
 /*!
  * \file
- * \brief Implementation of functions on vectors and matrices
- * \author Tony Ottosson and Adam Piatyszek
- * 
- * $Date$
- * $Revision$
+ * \brief Various functions on vectors and matrices - source file
+ * \author Tony Ottosson, Adam Piatyszek, Conrad Sanderson, Mark Dobossy
+ *         and Martin Senst
  *
  * -------------------------------------------------------------------------
  *
@@ -31,10 +29,11 @@
  */
 
 #include <itpp/base/matfunc.h>
-#include <itpp/base/schur.h>
+#include <itpp/base/algebra/schur.h>
 #include <itpp/base/converters.h>
 #include <limits>
 
+//! \cond
 
 namespace itpp {
 
@@ -78,7 +77,23 @@ namespace itpp {
   }
 
 
-  // ---------------------- Instantiations ------------------------------------
+  bool all(const bvec &testvec)
+  {
+    for (int i=0; i<testvec.length(); i++)
+      if (!testvec(i)) return false;
+    return true;
+  }
+
+  bool any(const bvec &testvec)
+  {
+    for (int i=0; i<testvec.length(); i++)
+      if (testvec(i)) return true;
+    return false;
+  }
+
+  // ----------------------------------------------------------------------
+  // Instantiations
+  // ----------------------------------------------------------------------
 
   template int length(const vec &v);
   template int length(const cvec &v);
@@ -86,7 +101,6 @@ namespace itpp {
   template int length(const ivec &v);
   template int length(const bvec &v);
 
-
   template double sum(const vec &v);
   template std::complex<double> sum(const cvec &v);
   template short sum(const svec &v);
@@ -112,8 +126,10 @@ namespace itpp {
   template bin prod(const bvec &v);
 
   template vec cross(const vec &v1, const vec &v2);
+  template cvec cross(const cvec &v1, const cvec &v2);
   template ivec cross(const ivec &v1, const ivec &v2);
   template svec cross(const svec &v1, const svec &v2);
+  template bvec cross(const bvec &v1, const bvec &v2);
 
   template vec reverse(const vec &in);
   template cvec reverse(const cvec &in);
@@ -121,33 +137,22 @@ namespace itpp {
   template ivec reverse(const ivec &in);
   template bvec reverse(const bvec &in);
 
-  template vec repeat(const vec &v, int norepeats);
-  template cvec repeat(const cvec &v, int norepeats);
-  template svec repeat(const svec &v, int norepeats);
-  template ivec repeat(const ivec &v, int norepeats);
-  template bvec repeat(const bvec &v, int norepeats);
-
-  template vec apply_function(float (*f)(float), const vec &data);
-  template vec apply_function(double (*f)(double), const vec &data);
-  template cvec apply_function(std::complex<double> (*f)(std::complex<double>), const cvec &data);
-  template svec apply_function(short (*f)(short), const svec &data);
-  template ivec apply_function(int (*f)(int), const ivec &data);
-  template bvec apply_function(bin (*f)(bin), const bvec &data);
-
-
-  template ivec zero_pad(const ivec &v, int n);
   template vec zero_pad(const vec &v, int n);
   template cvec zero_pad(const cvec &v, int n);
+  template ivec zero_pad(const ivec &v, int n);
+  template svec zero_pad(const svec &v, int n);
   template bvec zero_pad(const bvec &v, int n);
 
-  template ivec zero_pad(const ivec &v);
   template vec zero_pad(const vec &v);
   template cvec zero_pad(const cvec &v);
+  template ivec zero_pad(const ivec &v);
+  template svec zero_pad(const svec &v);
   template bvec zero_pad(const bvec &v);
 
   template mat  zero_pad(const mat &, int, int);
   template cmat zero_pad(const cmat &, int, int);
   template imat zero_pad(const imat &, int, int);
+  template smat zero_pad(const smat &, int, int);
   template bmat zero_pad(const bmat &, int, int);
 
   template vec sum(const mat &m, int dim);
@@ -156,6 +161,12 @@ namespace itpp {
   template ivec sum(const imat &m, int dim);
   template bvec sum(const bmat &m, int dim);
 
+  template double sumsum(const mat &X);
+  template std::complex<double> sumsum(const cmat &X);
+  template short sumsum(const smat &X);
+  template int sumsum(const imat &X);
+  template bin sumsum(const bmat &X);
+
   template vec sum_sqr(const mat & m, int dim);
   template cvec sum_sqr(const cmat &m, int dim);
   template svec sum_sqr(const smat &m, int dim);
@@ -169,10 +180,10 @@ namespace itpp {
   template bmat cumsum(const bmat &m, int dim);
 
   template vec prod(const mat &m, int dim);
-  // Template instantiation of product
   template cvec prod(const cmat &v, int dim);
   template svec prod(const smat &m, int dim);
   template ivec prod(const imat &m, int dim);
+  template bvec prod(const bmat &m, int dim);
 
   template vec diag(const mat &in);
   template cvec diag(const cmat &in);
@@ -219,7 +230,6 @@ namespace itpp {
   template imat transpose(const imat &m);
   template bmat transpose(const bmat &m);
 
-
   template void hermitian_transpose(const mat &m, mat &out);
   template void hermitian_transpose(const cmat &m, cmat &out);
   template void hermitian_transpose(const smat &m, smat &out);
@@ -232,79 +242,54 @@ namespace itpp {
   template imat hermitian_transpose(const imat &m);
   template bmat hermitian_transpose(const bmat &m);
 
-  template mat repeat(const mat &m, int norepeats);
-  template cmat repeat(const cmat &m, int norepeats);
-  template smat repeat(const smat &m, int norepeats);
-  template imat repeat(const imat &m, int norepeats);
-  template bmat repeat(const bmat &m, int norepeats);
-
-  template mat apply_function(float (*f)(float), const mat &data);
-  template mat apply_function(double (*f)(double), const mat &data);
-  template cmat apply_function(std::complex<double> (*f)(std::complex<double>), const cmat &data);
-  template smat apply_function(short (*f)(short), const smat &data);
-  template imat apply_function(int (*f)(int), const imat &data);
-  template bmat apply_function(bin (*f)(bin), const bmat &data);
-
-  template  vec rvectorize(const  mat &m);
+  template vec rvectorize(const mat &m);
   template cvec rvectorize(const cmat &m);
-  template  ivec rvectorize(const  imat &m);
-  template  bvec rvectorize(const  bmat &m);
+  template ivec rvectorize(const imat &m);
+  template svec rvectorize(const smat &m);
+  template bvec rvectorize(const bmat &m);
 
-  template  vec cvectorize(const  mat &m);
+  template vec cvectorize(const mat &m);
   template cvec cvectorize(const cmat &m);
-  template  ivec cvectorize(const  imat &m);
-  template  bvec cvectorize(const  bmat &m);
+  template ivec cvectorize(const imat &m);
+  template svec cvectorize(const smat &m);
+  template bvec cvectorize(const bmat &m);
 
-  template  mat reshape(const  mat &m, int rows, int cols);
+  template mat reshape(const mat &m, int rows, int cols);
   template cmat reshape(const cmat &m, int rows, int cols);
-  template  imat reshape(const  imat &m, int rows, int cols);
-  template  bmat reshape(const  bmat &m, int rows, int cols);
+  template imat reshape(const imat &m, int rows, int cols);
+  template smat reshape(const smat &m, int rows, int cols);
+  template bmat reshape(const bmat &m, int rows, int cols);
 
-  template  mat reshape(const  vec &m, int rows, int cols);
+  template mat reshape(const vec &m, int rows, int cols);
   template cmat reshape(const cvec &m, int rows, int cols);
-  template  imat reshape(const  ivec &m, int rows, int cols);
-  template  bmat reshape(const  bvec &m, int rows, int cols);
+  template imat reshape(const ivec &m, int rows, int cols);
+  template smat reshape(const svec &m, int rows, int cols);
+  template bmat reshape(const bvec &m, int rows, int cols);
 
-  template vec upsample(const vec &v, int usf);
-  template cvec upsample(const cvec &v, int usf);
-  template svec upsample(const svec &v, int usf);
-  template ivec upsample(const ivec &v, int usf);
-  template bvec upsample(const bvec &v, int usf);
+  template mat kron(const mat &X, const mat &Y);
+  template cmat kron(const cmat &X, const cmat &Y);
+  template imat kron(const imat &X, const imat &Y);
+  template smat kron(const smat &X, const smat &Y);
+  template bmat kron(const bmat &X, const bmat &Y);
 
-  template mat upsample(const mat &v, int usf);
-  template cmat upsample(const cmat &v, int usf);
-  template smat upsample(const smat &v, int usf);
-  template imat upsample(const imat &v, int usf);
-  template bmat upsample(const bmat &v, int usf);
+  template vec repmat(const vec &v, int n);
+  template cvec repmat(const cvec &v, int n);
+  template ivec repmat(const ivec &v, int n);
+  template svec repmat(const svec &v, int n);
+  template bvec repmat(const bvec &v, int n);
 
-  template void upsample(const vec &v, int usf,  vec & u);
-  template void upsample(const cvec &v, int usf,  cvec & u);
-  template void upsample(const svec &v, int usf,  svec & u);
-  template void upsample(const ivec &v, int usf,  ivec & u);
-  template void upsample(const bvec &v, int usf,  bvec & u);
+  template mat repmat(const vec &v, int m, int n, bool transpose);
+  template cmat repmat(const cvec &v, int m, int n, bool transpose);
+  template imat repmat(const ivec &v, int m, int n, bool transpose);
+  template smat repmat(const svec &v, int m, int n, bool transpose);
+  template bmat repmat(const bvec &v, int m, int n, bool transpose);
 
-  template void upsample(const mat &v, int usf,  mat & u);
-  template void upsample(const cmat &v, int usf,  cmat & u);
-  template void upsample(const smat &v, int usf,  smat & u);
-  template void upsample(const imat &v, int usf,  imat & u);
-  template void upsample(const bmat &v, int usf,  bmat & u);
- 
-  template vec lininterp(const vec &v, int usf);
-  template cvec lininterp(const cvec &v, int usf);
-
-  template mat lininterp(const mat &v, int usf);
-  template cmat lininterp(const cmat &v, int usf);
-
-  template void lininterp(const vec &v, int usf,  vec & u);
-  template void lininterp(const cvec &v, int usf,  cvec & u);
-
-  template void lininterp(const mat &v, int usf,  mat & u);
-  template void lininterp(const cmat &v, int usf,  cmat & u);
-
-  template mat lininterp(const mat &m, const double f_base, const double f_ups, const int nrof_samples, const double t_start);
-  template cmat lininterp(const cmat &m, const double f_base, const double f_ups, const int nrof_samples, const double t_start);
-
-  template vec lininterp(const vec &v, const double f_base, const double f_ups, const int nrof_samples, const double t_start);
-  template cvec lininterp(const cvec &v, const double f_base, const double f_ups, const int nrof_samples, const double t_start);
+  template mat repmat(const mat &data, int m, int n);
+  template cmat repmat(const cmat &data, int m, int n);
+  template imat repmat(const imat &data, int m, int n);
+  template smat repmat(const smat &data, int m, int n);
+  template bmat repmat(const bmat &data, int m, int n);
 
 } // namespace itpp
+
+//! \endcond
