@@ -2,9 +2,6 @@
  * \file
  * \brief Definition of classes for random number generators
  * \author Tony Ottosson and Adam Piatyszek
- * 
- * $Date$
- * $Revision$
  *
  * -------------------------------------------------------------------------
  *
@@ -41,7 +38,7 @@ namespace itpp {
 
   //! \addtogroup randgen
 
-  /*! 
+  /*!
    * \brief Base class for random (stochastic) sources.
    * \ingroup randgen
    *
@@ -69,12 +66,12 @@ namespace itpp {
    * Reference:
    * M. Matsumoto and T. Nishimura, "Mersenne Twister: A 623-Dimensionally
    * Equidistributed Uniform Pseudo-Random Number Generator", ACM Transactions
-   * on Modeling and Computer Simulation, Vol. 8, No. 1, January 1998, pp. 
+   * on Modeling and Computer Simulation, Vol. 8, No. 1, January 1998, pp.
    * 3-30.
    *
    * Copyright (C) 1997 - 2002, Makoto Matsumoto and Takuji Nishimura,
    * Copyright (C) 2000 - 2003, Richard J. Wagner
-   * All rights reserved.                          
+   * All rights reserved.
    *
    * Redistribution and use in source and binary forms, with or without
    * modification, are permitted provided that the following conditions
@@ -114,20 +111,23 @@ namespace itpp {
    */
   class Random_Generator {
   public:
-    //! Construct a new Random_Generator.    
-    Random_Generator();
+    //! Construct a new Random_Generator.
+    Random_Generator() { if (!initialized) reset(4357U); }
+    //! Construct Random_Generator object using \c seed
+    Random_Generator(unsigned int seed) { reset(seed); }
     //! Set the seed to a semi-random value (based on hashed time and clock).
-    void randomize();
+    void randomize() { reset(hash(time(0), clock())); }
     //! Reset the source. The same sequance will be generated as the last time.
-    void reset() { initialize(lastSeed); reload(); }
+    void reset() { initialize(last_seed); reload(); initialized = true; }
     //! Reset the source after setting the seed to seed.
-    void reset(unsigned int seed) { lastSeed = seed; initialize(lastSeed); reload(); }
+    void reset(unsigned int seed) { last_seed = seed; reset(); }
+
     //! Return a uniformly distributed [0,2^32-1] integer.
     unsigned int random_int()
     {
       if( left == 0 ) reload();
       --left;
-		
+
       register unsigned int s1;
       s1 = *pNext++;
       s1 ^= (s1 >> 11);
@@ -137,17 +137,28 @@ namespace itpp {
     }
 
     //! Return a uniformly distributed (0,1) value.
-    double random_01() { return (double(random_int()) + 0.5) * (1.0/4294967296.0); }
+    double random_01() { return (random_int() + 0.5) * (1.0/4294967296.0); }
+    //! Return a uniformly distributed [0,1) value.
+    double random_01_lclosed() { return random_int() * (1.0/4294967296.0); }
     //! Return a uniformly distributed [0,1] value.
-    double random_01_closed() { return double(random_int()) * (1.0/4294967295.0); }
+    double random_01_closed() { return random_int() * (1.0/4294967295.0); }
+    //! Return a uniformly distributed [0,1) value in 53-bit resolution.
+    double random53_01_lclosed()
+    {
+      return ((random_int() >> 5) * 67108864.0 + (random_int() >> 6))
+	* (1.0/9007199254740992.0); // by Isaku Wada
+    }
+
     //! Save current full state of generator in memory
     void get_state(ivec &out_state);
     //! Resume the state saved in memory. Clears memory.
     void set_state(ivec &new_state);
-  protected:
+
   private:
+    //! initialization flag
+    static bool initialized;
     //! seed used for initialisation
-    unsigned int lastSeed;
+    unsigned int last_seed;
     //! internal state
     static unsigned int state[624];
     //! next value to get from state
@@ -155,28 +166,32 @@ namespace itpp {
     //! number of values left before reload needed
     static int left;
 
-    //!
+    /*!
+     * \brief Initialize generator state with seed.
+     * See Knuth TAOCP Vol 2, 3rd Ed, p.106 for multiplier.
+     * \note In previous versions, most significant bits (MSBs) of the seed
+     * affect only MSBs of the state array. Modified 9 Jan 2002 by Makoto
+     * Matsumoto.
+     */
     void initialize( unsigned int seed )
     {
-      // Initialize generator state with seed
-      // See Knuth TAOCP Vol 2, 3rd Ed, p.106 for multiplier.
-      // In previous versions, most significant bits (MSBs) of the seed affect
-      // only MSBs of the state array.  Modified 9 Jan 2002 by Makoto Matsumoto.
       register unsigned int *s = state;
       register unsigned int *r = state;
       register int i = 1;
       *s++ = seed & 0xffffffffU;
-      for( ; i < 624; ++i ) 
+      for( ; i < 624; ++i )
 	{
 	  *s++ = ( 1812433253U * ( *r ^ (*r >> 30) ) + i ) & 0xffffffffU;
 	  r++;
 	}
     }
-    //!
+
+    /*!
+     * \brief Generate N new values in state.
+     * Made clearer and faster by Matthew Bellew (matthew.bellew@home.com)
+     */
     void reload()
     {
-      // Generate N new values in state
-      // Made clearer and faster by Matthew Bellew (matthew.bellew@home.com)
       register unsigned int *p = state;
       register int i;
       for( i = 624 - 397; i--; ++p )
@@ -184,7 +199,7 @@ namespace itpp {
       for( i = 397; --i; ++p )
 	*p = twist( p[397-624], p[0], p[1] );
       *p = twist( p[397-624], p[0], state[0] );
-      
+
       left = 624, pNext = state;
     }
     //!
@@ -201,7 +216,7 @@ namespace itpp {
      * ----------------------------------------------------------------------
      * --- ediap - 2007/01/17 ---
      * ----------------------------------------------------------------------
-     * Richard's implementation of the twist() function is was follows:
+     * Wagners's implementation of the twist() function was as follows:
      *  { return m ^ (mixBits(s0,s1)>>1) ^ (-loBit(s1) & 0x9908b0dfU); }
      * However, this code caused a warning/error under MSVC++, because
      * unsigned value loBit(s1) is being negated with `-' (c.f. bug report
@@ -211,7 +226,7 @@ namespace itpp {
      *  #define UMASK 0x80000000UL
      *  #define LMASK 0x7fffffffUL
      *  #define MIXBITS(u,v) ( ((u) & UMASK) | ((v) & LMASK) )
-     *  #define TWIST(u,v) ((MIXBITS(u,v) >> 1) ^ ((v)&1UL ? MATRIX_A : 0UL)) 
+     *  #define TWIST(u,v) ((MIXBITS(u,v) >> 1) ^ ((v)&1UL ? MATRIX_A : 0UL))
      * ----------------------------------------------------------------------
      */
     //!
@@ -227,7 +242,7 @@ namespace itpp {
   //!@{
 
   //! Set the seed of the Global Random Number Generator
-  void RNG_reset(unsigned long seed);
+  void RNG_reset(unsigned int seed);
   //! Set the seed of the Global Random Number Generator to the same as last reset/init
   void RNG_reset();
   //! Set a random seed for the Global Random Number Generator.
@@ -238,7 +253,7 @@ namespace itpp {
   void RNG_set_state(ivec &state);
   //!@}
 
-  /*! 
+  /*!
     \brief Bernoulli distribution
     \ingroup randgen
   */
@@ -268,7 +283,7 @@ namespace itpp {
     void sample_vector(int size, bvec &out)
     {
       out.set_size(size, false);
-      for (int i=0; i<size; i++) out(i) = sample(); 
+      for (int i=0; i<size; i++) out(i) = sample();
     }
     //! Get a sample matrix.
     void sample_matrix(int rows, int cols, bmat &out)
@@ -284,18 +299,18 @@ namespace itpp {
     Random_Generator RNG;
   };
 
-  /*! 
+  /*!
     \brief Integer uniform distribution
     \ingroup randgen
-  
+
     Example: Generation of random uniformly distributed integers in the interval [0,10].
     \code
     #include "itpp/sigproc.h"
-  
+
     int main() {
-  
+
     I_Uniform_RNG gen(0, 10);
-  
+
     cout << gen() << endl; // prints a random integer
     cout << gen(10) << endl; // prints 10 random integers
     }
@@ -340,26 +355,38 @@ namespace itpp {
     //! get parameters
     void get_setup(double &min, double &max) const;
     //! Get one sample.
-    double operator()() { return ( sample()* (hi_bound - lo_bound) + lo_bound ); }
+    double operator()() { return (sample() * (hi_bound - lo_bound) + lo_bound); }
     //! Get a sample vector.
     vec operator()(int n)
-    { vec temp(n); sample_vector(n, temp); return (temp *(hi_bound - lo_bound) + lo_bound); }
+    {
+      vec temp(n);
+      sample_vector(n, temp);
+      temp *= hi_bound - lo_bound;
+      temp += lo_bound;
+      return temp;
+    }
     //! Get a sample matrix.
     mat operator()(int h, int w)
-    { mat temp(h,w); sample_matrix(h,w, temp); return (temp *(hi_bound - lo_bound) + lo_bound); }
-    //! Get a Uniformly distributed (0,1) sample 
+    {
+      mat temp(h, w);
+      sample_matrix(h, w, temp);
+      temp *= hi_bound - lo_bound;
+      temp += lo_bound;
+      return temp;
+    }
+    //! Get a Uniformly distributed (0,1) sample
     double sample() {  return RNG.random_01(); }
     //! Get a Uniformly distributed (0,1) vector
     void sample_vector(int size, vec &out)
     {
       out.set_size(size, false);
-      for (int i=0; i<size; i++) out(i) = sample(); 
+      for (int i=0; i<size; i++) out(i) = sample();
     }
     //! Get a Uniformly distributed (0,1) matrix
     void sample_matrix(int rows, int cols, mat &out)
     {
       out.set_size(rows, cols, false);
-      for (int i=0; i<rows*cols; i++) out(i) = sample(); 
+      for (int i=0; i<rows*cols; i++) out(i) = sample();
     }
   protected:
   private:
@@ -398,70 +425,112 @@ namespace itpp {
   };
 
   /*!
-    \brief Normal distribution
-    \ingroup randgen
-  */
+   * \brief Normal distribution
+   * \ingroup randgen
+   *
+   * Normal (Gaussian) random variables, using a simplified Ziggurat method.
+   *
+   * For details see the following arcticle: George Marsaglia, Wai Wan
+   * Tsang, "The Ziggurat Method for Generating Random Variables", Journal
+   * of Statistical Software, vol. 5 (2000), no. 8
+   *
+   * This implementation is based on the generator written by Jochen Voss
+   * found at http://seehuhn.de/comp/ziggurat/, which is also included in
+   * the GSL library (randlist/gauss.c).
+   */
   class Normal_RNG {
   public:
     //! Constructor. Set mean and variance.
-    Normal_RNG(double meanval, double variance) { setup(meanval, variance); };
+    Normal_RNG(double meanval, double variance):
+      mean(meanval), sigma(std::sqrt(variance)) {}
     //! Constructor. Set mean and variance.
-    Normal_RNG() { mean = 0.0; sigma = 1.0; odd = false; }
+    Normal_RNG(): mean(0.0), sigma(1.0) {}
     //! Set mean, and variance
     void setup(double meanval, double variance)
-    { mean = meanval; sigma = std::sqrt(variance); odd = false; }
+    { mean = meanval; sigma = std::sqrt(variance); }
     //! Get mean and variance
     void get_setup(double &meanval, double &variance) const;
     //! Get one sample.
     double operator()() { return (sigma*sample()+mean); }
     //! Get a sample vector.
-    vec operator()(int n) { vec temp(n); sample_vector(n, temp); return (sigma*temp+mean); }
-    //! Get a sample matrix.
-    mat operator()(int h, int w) { mat temp(h,w); sample_matrix(h,w, temp); return (sigma*temp+mean); }
-    //! Get a Normal distributed (0,1) sample
-    double sample() // Box-Mueller, Polar version, See Knuth v2, 3rd ed, p122 
+    vec operator()(int n)
     {
-      double x, r2;
-      if (odd) {
-	odd = 0;
-	return y;
-      }
-      do { x = 2. * RNG.random_01() - 1.; y = 2. * RNG.random_01() - 1.; r2 = x*x + y*y; } while (r2 >= 1. || r2 < 1E-30);
-      r2 = std::sqrt(std::log(r2)*(-2./r2)); x *= r2;  y *= r2; odd = 1;
-      return x;
+      vec temp(n);
+      sample_vector(n, temp);
+      temp *= sigma;
+      temp += mean;
+      return temp;
     }
- 
+    //! Get a sample matrix.
+    mat operator()(int h, int w)
+    {
+      mat temp(h, w);
+      sample_matrix(h, w, temp);
+      temp *= sigma;
+      temp += mean;
+      return temp;
+    }
+    //! Get a Normal distributed (0,1) sample
+    double sample()
+    {
+      unsigned int u, sign, i, j;
+      double x, y;
+
+      while(true) {
+	u = RNG.random_int();
+	sign = u & 0x80; // 1 bit for the sign
+	i = u & 0x7f; // 7 bits to choose the step
+	j = u >> 8; // 24 bits for the x-value
+
+	x = j * wtab[i];
+
+	if (j < ktab[i])
+	  break;
+
+	if (i < 127) {
+	  y = ytab[i+1] + (ytab[i] - ytab[i+1]) * RNG.random_01();
+	}
+	else {
+	  x = PARAM_R - std::log(1.0 - RNG.random_01()) / PARAM_R;
+	  y = std::exp(-PARAM_R * (x - 0.5 * PARAM_R)) * RNG.random_01();
+	}
+
+	if (y < std::exp(-0.5 * x * x))
+	  break;
+      }
+      return sign ? x : -x;
+    }
+
     //! Get a Normal distributed (0,1) vector
     void sample_vector(int size, vec &out)
     {
       out.set_size(size, false);
-      for (int i=0; i<size; i++) out(i) = sample(); 
+      for (int i=0; i<size; i++) out(i) = sample();
     }
 
     //! Get a Normal distributed (0,1) matrix
     void sample_matrix(int rows, int cols, mat &out)
     {
       out.set_size(rows, cols, false);
-      for (int i=0; i<rows*cols; i++) out(i) = sample(); 
+      for (int i=0; i<rows*cols; i++) out(i) = sample();
     }
-  protected:
   private:
-    //!
-    double mean, sigma, y;
-    //!
-    int odd;
-    //!
+    double mean, sigma;
+    static const double ytab[128];
+    static const unsigned int ktab[128];
+    static const double wtab[128];
+    static const double PARAM_R;
     Random_Generator RNG;
   };
 
-  /*! 
+  /*!
     \brief Laplacian distribution
     \ingroup randgen
   */
   class Laplace_RNG {
   public:
     //! Constructor. Set mean and variance.
-    Laplace_RNG(double meanval=0.0, double variance=1.0);
+    Laplace_RNG(double meanval = 0.0, double variance = 1.0);
     //! Set mean and variance
     void setup(double meanval, double variance);
     //! Get mean and variance
@@ -475,22 +544,16 @@ namespace itpp {
     //! Returns a single sample
     double sample()
     {
-      u=RNG.random_01();
-      if(u<0.5)
-	l=std::log(2.0*u);
+      double u = RNG.random_01();
+      double l = sqrt_12var;
+      if (u < 0.5)
+	l *= std::log(2.0 * u);
       else
-	l=-std::log(2.0*(1-u));
-      
-      l *= std::sqrt(var/2.0);
-      l += mean;
-      
-      return l;
+	l *= -std::log(2.0 * (1-u));
+      return (l + mean);
     }
-  protected:
   private:
-    //!
-    double mean, var, u, l;
-    //!
+    double mean, var, sqrt_12var;
     Random_Generator RNG;
   };
 
@@ -501,48 +564,69 @@ namespace itpp {
   class Complex_Normal_RNG {
   public:
     //! Constructor. Set mean and variance.
-    Complex_Normal_RNG(std::complex<double> mean, double variance) { setup(mean, variance); }
-    //! Constructor. Set mean and variance.
-    Complex_Normal_RNG() { m = 0.0; sigma=1.0; }
+    Complex_Normal_RNG(std::complex<double> mean, double variance):
+      norm_factor(1.0/std::sqrt(2.0))
+    {
+      setup(mean, variance);
+    }
+    //! Default constructor
+    Complex_Normal_RNG(): m(0.0), sigma(1.0), norm_factor(1.0/std::sqrt(2.0)) {}
     //! Set mean and variance
-    void setup(std::complex<double> mean, double variance) { m = mean; sigma = std::sqrt(variance); }
+    void setup(std::complex<double> mean, double variance)
+    {
+      m = mean; sigma = std::sqrt(variance);
+    }
     //! Get mean and variance
-    void get_setup(std::complex<double> &mean, double &variance) { mean = m; variance = sigma*sigma; }
+    void get_setup(std::complex<double> &mean, double &variance)
+    {
+      mean = m; variance = sigma*sigma;
+    }
     //! Get one sample.
     std::complex<double> operator()() { return sigma*sample()+m; }
     //! Get a sample vector.
-    cvec operator()(int n) { cvec temp(n); sample_vector(n, temp); return (sigma*temp+m); }
+    cvec operator()(int n)
+    {
+      cvec temp(n);
+      sample_vector(n, temp);
+      temp *= sigma;
+      temp += m;
+      return temp;
+    }
     //! Get a sample matrix.
-    cmat operator()(int h, int w) { cmat temp(h,w); sample_matrix(h,w, temp); return (sigma*temp+m); }
+    cmat operator()(int h, int w)
+    {
+      cmat temp(h, w);
+      sample_matrix(h, w, temp);
+      temp *= sigma;
+      temp += m;
+      return temp;
+    }
     //! Get a Complex Normal (0,1) distributed sample
     std::complex<double> sample()
     {
-      double a = m_2pi * RNG.random_01();
-      double b = std::sqrt(-std::log(RNG.random_01()));
-      return std::complex<double>(b * std::cos(a), b * std::sin(a));
+      double a = nRNG.sample() * norm_factor;
+      double b = nRNG.sample() * norm_factor;
+      return std::complex<double>(a, b);
     }
 
     //! Get a Complex Normal (0,1) distributed vector
     void sample_vector(int size, cvec &out)
     {
       out.set_size(size, false);
-      for (int i=0; i<size; i++) out(i) = sample(); 
+      for (int i=0; i<size; i++) out(i) = sample();
     }
 
     //! Get a Complex Normal (0,1) distributed matrix
     void sample_matrix(int rows, int cols, cmat &out)
     {
       out.set_size(rows, cols, false);
-      for (int i=0; i<rows*cols; i++) out(i) = sample(); 
+      for (int i=0; i<rows*cols; i++) out(i) = sample();
     }
-  protected:
   private:
-    //!
     std::complex<double> m;
-    //!
     double sigma;
-    //!
-    Random_Generator RNG;
+    const double norm_factor;
+    Normal_RNG nRNG;
   };
 
   /*!
@@ -552,7 +636,8 @@ namespace itpp {
   class AR1_Normal_RNG {
   public:
     //! Constructor. Set mean, variance, and correlation.
-    AR1_Normal_RNG(double meanval=0.0, double variance=1.0, double rho=0.0);
+    AR1_Normal_RNG(double meanval = 0.0, double variance = 1.0,
+		   double rho = 0.0);
     //! Set mean, variance, and correlation
     void setup(double meanval, double variance, double rho);
     //! Get mean, variance and correlation
@@ -565,16 +650,23 @@ namespace itpp {
     vec operator()(int n);
     //! Get a sample matrix.
     mat operator()(int h, int w);
-
-  protected:
-  private: 
-    //!
-    double sample();
-    //!
-    double my_mean, mem, r, factr, mean, var, r1, r2;
-    //!
+  private:
+    double sample()
+    {
+      mem *= r;
+      if (odd) {
+	r1 = m_2pi * RNG.random_01();
+	r2 = std::sqrt(factr * std::log(RNG.random_01()));
+	mem += r2 * std::cos(r1);
+      }
+      else {
+	mem += r2 * std::sin(r1);
+      }
+      odd = !odd;
+      return (mem + mean);
+    }
+    double mem, r, factr, mean, var, r1, r2;
     bool odd;
-    //!
     Random_Generator RNG;
   };
 
@@ -584,7 +676,7 @@ namespace itpp {
   */
   typedef Normal_RNG Gauss_RNG;
 
-  /*! 
+  /*!
     \brief AR1_Gauss_RNG is the same as AR1_Normal_RNG
     \ingroup randgen
   */
@@ -597,41 +689,37 @@ namespace itpp {
   class Weibull_RNG {
   public:
     //! Constructor. Set lambda and beta.
-    Weibull_RNG(double lambda=1.0, double beta=1.0);
-
+    Weibull_RNG(double lambda = 1.0, double beta = 1.0);
     //! Set lambda, and beta
     void setup(double lambda, double beta);
     //! Get lambda and beta
-    void get_setup(double &lambda, double &beta) { lambda=l; beta=b; }
+    void get_setup(double &lambda, double &beta) { lambda = l; beta = b; }
     //! Get one sample.
     double operator()() { return sample(); }
     //! Get a sample vector.
     vec operator()(int n);
     //! Get a sample matrix.
     mat operator()(int h, int w);
-  protected:
   private:
-    //!
-    double sample();
-    //!
+    double sample()
+    {
+      return (std::pow(-std::log(RNG.random_01()), 1.0/b) / l);
+    }
     double l, b;
-    //!
     double mean, var;
-    //!
     Random_Generator RNG;
   };
 
-  /*! 
+  /*!
     \brief Rayleigh distribution
     \ingroup randgen
   */
   class Rayleigh_RNG {
   public:
     //! Constructor. Set sigma.
-    Rayleigh_RNG(double sigma=1.0);
-
+    Rayleigh_RNG(double sigma = 1.0);
     //! Set sigma
-    void setup(double sigma) { sig=sigma; }
+    void setup(double sigma) { sig = sigma; }
     //! Get sigma
     double get_setup() { return sig; }
     //! Get one sample.
@@ -640,42 +728,46 @@ namespace itpp {
     vec operator()(int n);
     //! Get a sample matrix.
     mat operator()(int h, int w);
-  protected:
   private:
-    //!
-    double sample();
-    //!
+    double sample()
+    {
+      double s1 = nRNG.sample();
+      double s2 = nRNG.sample();
+      // s1 and s2 are N(0,1) and independent
+      return (sig * std::sqrt(s1*s1 + s2*s2));
+    }
     double sig;
-    //!
-    Random_Generator RNG;
+    Normal_RNG nRNG;
   };
 
-  /*! 
+  /*!
     \brief Rice distribution
     \ingroup randgen
   */
   class Rice_RNG {
   public:
-    //! Constructor. Set sigma, and s.
-    Rice_RNG(double sigma=1.0, double _s=1.0);
-    //! Set sigma, and s
-    void setup(double sigma, double _s) { sig=sigma; s=_s; }
+    //! Constructor. Set sigma, and v (if v = 0, Rice -> Rayleigh).
+    Rice_RNG(double sigma = 1.0, double v = 1.0);
+    //! Set sigma, and v (if v = 0, Rice -> Rayleigh).
+    void setup(double sigma, double v) { sig = sigma; s = v; }
     //! Get parameters
-    void get_setup(double &sigma, double &_s) { sigma=sig; _s=s; }
-    //! Get one sample.
+    void get_setup(double &sigma, double &v) { sigma = sig; v = s; }
+    //! Get one sample
     double operator()() { return sample(); }
-    //! Get a sample vector.
+    //! Get a sample vector
     vec operator()(int n);
-    //! Get a sample matrix.
+    //! Get a sample matrix
     mat operator()(int h, int w);
-  protected:
   private:
-    //!
-    double sample();
-    //!
+    double sample()
+    {
+      double s1 = nRNG.sample() + s;
+      double s2 = nRNG.sample();
+      // s1 and s2 are N(0,1) and independent
+      return (sig * std::sqrt(s1*s1 + s2*s2));
+    }
     double sig, s;
-    //!
-    Random_Generator RNG;
+    Normal_RNG nRNG;
   };
 
   //! \addtogroup randgen
@@ -705,9 +797,9 @@ namespace itpp {
 
   //! Generates a random integer in the interval [low,high]
   inline int randi(int low, int high) { I_Uniform_RNG src; src.setup(low, high); return src(); }
-  //! Generates a random ivec with elements in the interval [low,high] 
+  //! Generates a random ivec with elements in the interval [low,high]
   inline ivec randi(int size, int low, int high) { I_Uniform_RNG src; src.setup(low, high); return src(size); }
-  //! Generates a random imat with elements in the interval [low,high] 
+  //! Generates a random imat with elements in the interval [low,high]
   inline imat randi(int rows, int cols, int low, int high) { I_Uniform_RNG src; src.setup(low, high); return src(rows, cols); }
 
   //! Generates a random Rayleigh vector
@@ -731,7 +823,7 @@ namespace itpp {
   inline mat randn(int rows, int cols){ mat temp; randn(rows, cols, temp); return temp; }
 
   /*! \brief Generates a random complex Gaussian (0,1) variable
-    
+
   The real and imaginary parts are independent and have variances equal to 0.5
   */
   inline std::complex<double> randn_c(void) { Complex_Normal_RNG src; return src.sample(); }
@@ -746,64 +838,6 @@ namespace itpp {
 
   //!@}
 
-  // -------------------- INLINES ----------------------------------------------
-
-  inline double AR1_Normal_RNG::sample()
-  {
-    double s;
-
-    if (odd) {
-      r1 = RNG.random_01();
-      r2 = RNG.random_01();
-      s = std::sqrt(factr * std::log(r2)) * std::cos(m_2pi * r1);
-    } else
-      s = std::sqrt(factr * std::log(r2)) * std::sin(m_2pi * r1);
-
-    odd = !odd;
-  
-    mem = s + r * mem;
-    s = mem + mean;
-  
-    return s;
-  }
-
-  inline double Weibull_RNG::sample()
-  {
-    return ( std::pow(-std::log(RNG.random_01()), 1.0/b) / l );
-  }
-
-  inline double Rayleigh_RNG::sample()
-  {
-    double r1, r2;
-    double s1, s2, samp;
-
-    r1 = RNG.random_01();
-    r2 = RNG.random_01();
-    s1 = std::sqrt(-2.0 * std::log(r2)) * std::cos(m_2pi * r1);
-    s2 = std::sqrt(-2.0 * std::log(r2)) * std::sin(m_2pi * r1);
-    // s1 and s2 are N(0,1) and independent
-    samp = sig * std::sqrt(s1*s1 + s2*s2);
-     
-    return samp;
-  }
-
-  inline double Rice_RNG::sample()
-  {
-    double r1, r2;
-    double s1, s2, samp;
-    double m1 = 0.0;
-    double m2 = std::sqrt(s*s - m1*m1);
-
-    r1 = RNG.random_01();
-    r2 = RNG.random_01();
-    s1 = std::sqrt(-2.0 * std::log(r2)) * std::cos(m_2pi * r1);
-    s2 = std::sqrt(-2.0 * std::log(r2)) * std::sin(m_2pi * r1);
-    // s1 and s2 are N(0,1) and independent
-    samp = std::sqrt((sig*s1+m1) * (sig*s1+m1) + (sig*s2+m2) * (sig*s2+m2));
-      
-    return samp;
-  }
-
 } // namespace itpp
 
 #endif // #ifndef RANDOM_H
