@@ -1,10 +1,7 @@
 /*!
  * \file
  * \brief Implementation of special vectors and matrices
- * \author Tony Ottosson, Tobias Ringstrom, Pal Frenger and Adam Piatyszek
- * 
- * $Date$
- * $Revision$
+ * \author Tony Ottosson, Tobias Ringstrom, Pal Frenger, Adam Piatyszek and Erik G. Larsson
  *
  * -------------------------------------------------------------------------
  *
@@ -31,12 +28,12 @@
  */
 
 #include <itpp/base/specmat.h>
-#include <itpp/base/elmatfunc.h>
+#include <itpp/base/math/elem_math.h>
+#include <itpp/base/math/log_exp.h>
 #include <itpp/base/matfunc.h>
-#include <itpp/base/stat.h>
 
 
-namespace itpp { 
+namespace itpp {
 
   ivec find(const bvec &invector)
   {
@@ -52,7 +49,7 @@ namespace itpp {
     return temp;
   }
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
+//! \cond
 
 #define CREATE_SET_FUNS(typef,typem,name,value)	\
   typef name(int size)				\
@@ -77,7 +74,7 @@ namespace itpp {
       t(i,i) = one;				\
     return t;					\
   }
-  
+
   CREATE_SET_FUNS(vec, mat, ones, 1.0)
   CREATE_SET_FUNS(bvec, bmat, ones_b, bin(1))
   CREATE_SET_FUNS(ivec, imat, ones_i, 1)
@@ -102,7 +99,7 @@ namespace itpp {
       m(i,i) = T(1);
   }
 
-#endif //DOXYGEN_SHOULD_SKIP_THIS
+//! \endcond
 
   vec impulse(int size) {
     vec	t(size);
@@ -128,25 +125,45 @@ namespace itpp {
     }
   }
 
+  vec zigzag_space(double t0, double t1, int K)
+  {
+    it_assert(K>0,"zigzag_space:() K must be positive");
+    ivec N="0 1";
+
+    int n=2;
+    for (int k=0; k<K; k++) {
+      ivec Nn=2*N;
+      for (int i=1; i<length(Nn); i+=2)  {
+	Nn=concat(Nn,i);
+	n++;
+      }
+      N=Nn;
+    }
+
+    vec T0=linspace(t0,t1,n);
+    vec Tt=zeros(n);
+    for (int i=0; i<n; i++) {
+      Tt(i)=T0(N(i));
+    }
+    return Tt;
+  }
 
   // Construct a Hadamard-imat of size "size"
-  imat hadamard(int size) {	
-    int i,k,l,pow2,logsize;
-    imat H(size,size);
-    logsize = levels2bits(size);
+  imat hadamard(int size) {
+    it_assert(size > 0, "hadamard(): size is not a power of 2");
+    int logsize = ceil_i(::log2(static_cast<double>(size)));
+    it_assert(pow2i(logsize) == size, "hadamard(): size is not a power of 2");
 
-    it_assert1(pow2i(logsize)==size,"hadamard size not a power of 2");
-    H(0,0)=1;H(0,1)=1;H(1,0)=1;H(1,1)=-1;
-	
-    for (i=1;i<logsize;i++) {
-      // 	pow2=round_i(pow(2,i));  // Unbeliveably slow
-      pow2 = 1<<i;
-      for (k=0;k<pow2;k++) {
-	for (l=0;l<pow2;l++) {
-	  H(k,l)=H(k,l);
-	  H(k+pow2,l)=H(k,l);
-	  H(k,l+pow2)=H(k,l);
-	  H(k+pow2,l+pow2)=(-1)*H(k,l);
+    imat H(size, size); H(0,0) = 1;
+
+    for (int i = 0; i < logsize; ++i) {
+      int pow2 = 1 << i;
+      for (int k = 0; k < pow2; ++k) {
+	for (int l = 0; l < pow2; ++l) {
+	  H(k, l) = H(k, l);
+	  H(k+pow2, l) = H(k, l);
+	  H(k, l+pow2) = H(k, l);
+	  H(k+pow2, l+pow2) = (-1) * H(k, l);
 	}
       }
     }
@@ -160,12 +177,12 @@ namespace itpp {
     int i, j;
 
     out = -1; // start with all elements equal to "-1"
-  
+
     // Generate a complete list of quadratic residues
     for (i=0; i<(p-1)/2; i++) {
       quadratic_residue=((i+1)*(i+1))%p;
       // set this element in all rows (col-row) = quadratic_residue
-      for (j=0; j<p; j++) { 
+      for (j=0; j<p; j++) {
 	out(j, (j+quadratic_residue)%p)=1;
       }
     }
@@ -179,7 +196,7 @@ namespace itpp {
 
   imat conference(int n)
   {
-    it_assert1(n%4 == 2, "conference(int n); wrong size");
+    it_assert_debug(n%4 == 2, "conference(int n); wrong size");
     int pm=n-1; // p must be odd prime, not checked
     imat out(n,n);
 
@@ -193,7 +210,7 @@ namespace itpp {
 
   cmat toeplitz(const cvec &c, const cvec &r) {
     int size = c.size();
-    it_assert(size == r.size(), 
+    it_assert(size == r.size(),
 	      "toeplitz(): Incorrect sizes of input vectors.");
     cmat output(size, size);
     cvec c_conj = conj(c);
@@ -266,7 +283,7 @@ namespace itpp {
   {
     mat m;
     double c = std::cos(angle), s = std::sin(angle);
-  
+
     it_assert(plane1>=0 && plane2>=0 &&
 	      plane1<dim && plane2<dim && plane1!=plane2,
 	      "Invalid arguments to rotation_matrix()");
@@ -295,7 +312,7 @@ namespace itpp {
       beta = 0.0;
       return;
     }
-    sigma = energy(x(1, n-1));
+    sigma = sum(sqr(x(1, n-1)));
     v(0) = 1.0;
     if (sigma == 0.0)
       beta = 0.0;
@@ -313,7 +330,7 @@ namespace itpp {
   void givens(double a, double b, double &c, double &s)
   {
     double t;
-    
+
     if (b == 0) {
       c = 1.0;
       s = 0.0;
@@ -337,7 +354,7 @@ namespace itpp {
     double t, c, s;
 
     m.set_size(2,2);
-    
+
     if (b == 0) {
       m(0,0) = 1.0;
       m(1,1) = 1.0;
@@ -375,7 +392,7 @@ namespace itpp {
     double t, c, s;
 
     m.set_size(2,2);
-    
+
     if (b == 0) {
       m(0,0) = 1.0;
       m(1,1) = 1.0;
