@@ -2,9 +2,6 @@
  * \file
  * \brief Sparse Vector Class definitions
  * \author Tony Ottosson and Tobias Ringstrom
- * 
- * $Date$
- * $Revision$
  *
  * -------------------------------------------------------------------------
  *
@@ -33,8 +30,14 @@
 #ifndef SVEC_H
 #define SVEC_H
 
+#ifndef _MSC_VER
+#  include <itpp/config.h>
+#else
+#  include <itpp/config_msvc.h>
+#endif
+
 #include <itpp/base/vec.h>
-#include <itpp/base/stat.h>
+#include <itpp/base/math/min_max.h>
 #include <cstdlib>
 
 
@@ -83,13 +86,15 @@ namespace itpp {
   template <class T>
     Sparse_Vec<T> elem_mult_s(const Vec<T> &v1, const Sparse_Vec<T> &v2);
 
-  /*! 
+  /*!
     \brief Templated sparse vector class
     \author Tony Ottosson and Tobias Ringstrom
 
-    A sparse vector is a vector where most elements are zero. The maximum number of
-    none-zero elements is a parameter to the constructor.
-    
+    A sparse vector is a vector where most elements are zero. The
+    maximum number of none-zero elements is a parameter to the
+    constructor. The elements are stored in random order, i.e. they
+    are not sorted.
+
   */
   template <class T>
     class Sparse_Vec {
@@ -107,37 +112,37 @@ namespace itpp {
     Sparse_Vec(int sz, int data_init=200);
 
     /*!
-      \brief Initiate a new sparse vector. 
+      \brief Initiate a new sparse vector.
 
       \param v The elements of \c v are copied into the new sparse vector
     */
     Sparse_Vec(const Sparse_Vec<T> &v);
 
-    /*! 
-      \brief Initiate a new sparse vector from a dense vector. 
+    /*!
+      \brief Initiate a new sparse vector from a dense vector.
 
       \param v The elements of \c v are copied into the new sparse vector
     */
     Sparse_Vec(const Vec<T> &v);
 
-    /*! 
+    /*!
       \brief Initiate a new sparse vector from a dense vector. Elements of \c v larger than \c epsilon are copied into the new sparse vector.
-    
+
       \note If the type T is complex<double>, then the elements of \c v larger than \c abs(epsilon) are copied into the new sparse vector.
     */
     Sparse_Vec(const Vec<T> &v, T epsilon);
 
     //! Destructor
     ~Sparse_Vec();
-  
-    /*! 
+
+    /*!
       \brief Set the size \c sz of the sparse vector. Default value \c data_init=-1 \c => allocated size for the data is not changed.
 
       \param sz Size of the sparse vector (i.e. maximum index is (\c sz - 1))
       \param data_init Maximum number of non-zero elements in the sparse vector (default value -1 \c => allocated size for the data is not changed)
     */
     void set_size(int sz, int data_init=-1);
-  
+
     //! Returns the size of the sparse vector
     int size() const { return v_size; }
 
@@ -152,7 +157,7 @@ namespace itpp {
 
     //! Returns the density of the sparse vector: (number of non-zero elements)/(size of the vector)
     double density();
-  
+
     //! Set that all elements smaller than \a epsilon should be set to zero.
     void set_small_element(const T& epsilon);
 
@@ -162,8 +167,8 @@ namespace itpp {
       \note The small element \a epsilon can be set by the member function set_small_element. If no small value is set, the default value is always \c epsilon=0.
     */
     void remove_small_elements();
-  
-    /*! 
+
+    /*!
       \brief Set the maximum number of non-zero elements to \c new_size
 
       \param new_size The new maximum number of non-zero elements.
@@ -172,13 +177,13 @@ namespace itpp {
 
     //! Set the maximum number of non-zero elements equal to the actual number of non-zero elements
     void compact();
-  
+
     //! Returns a full, dense vector in \c v
     void full(Vec<T> &v) const;
 
     //! Returns a full, dense vector
     Vec<T> full() const;
-  
+
     //! Returns the element with index \c i
     T operator()(int i) const;
 
@@ -212,7 +217,7 @@ namespace itpp {
     //! Clear the i-th element (if it contains a non-zero value)
     void clear_elem(const int i);
 
-    /*! 
+    /*!
       \brief Extract the reference to the p-th non-zero data element
     */
     inline void get_nz_data(int p, T& data_out)
@@ -251,41 +256,44 @@ namespace itpp {
 	dat=data[p];
       }
 
+    //! Retrun the indices of non-zero values
+    ivec get_nz_indices();
+
     //! Return sparse subvector from index \c i1 to index \c i2
     Sparse_Vec<T> get_subvector(int i1, int i2) const;
-  
+
     //! Returns the sum of all values squared
     T sqr() const;
-  
+
     //! Assign sparse vector the value and length of the sparse vector \c v
     void operator=(const Sparse_Vec<T> &v);
     //! Assign sparse vector the value and length of the dense vector \c v
     void operator=(const Vec<T> &v);
-   
+
    //! Returns the sign inverse of all elements in the sparse vector
     Sparse_Vec<T> operator-() const;
 
     //! Compare two sparse vectors. False if wrong sizes or different values
     bool operator==(const Sparse_Vec<T> &v);
-  
+
     //! Add sparse vector \c v to all non-zero elements of the sparse vector
     void operator+=(const Sparse_Vec<T> &v);
-  
+
     //! Add vector \c v to all non-zero elements of the sparse vector
     void operator+=(const Vec<T> &v);
-  
+
     //! Subtract sparse vector \c v from all non-zero elements of the sparse vector
     void operator-=(const Sparse_Vec<T> &v);
-  
+
     //! Subtract vector \c v from all non-zero elements of the sparse vector
     void operator-=(const Vec<T> &v);
-  
+
     //! Multiply the scalar \c v to all non-zero elements of the sparse vector
     void operator*=(const T &v);
-  
+
     //! Divide all non-zero elements of the sparse vector with the scalar \c v
     void operator/=(const T &v);
-  
+
    //! Addition v1+v2 where v1 and v2 are sparse vector
     friend Sparse_Vec<T> operator+<>(const Sparse_Vec<T> &v1, const Sparse_Vec<T> &v2);
     //! Scalar product v1*v2 where v1 and v2 are sparse vectors
@@ -309,12 +317,12 @@ namespace itpp {
 
     //! Element wise multiplication of a a dense vector and a sparse vector returning a sparse vector
     friend Sparse_Vec<T> elem_mult_s <>(const Vec<T> &v1, const Sparse_Vec<T> &v2);
-  
+
     private:
     void init();
     void alloc();
     void free();
-  
+
     int v_size, used_size, data_size;
     T *data;
     int *index;
@@ -322,19 +330,20 @@ namespace itpp {
     bool check_small_elems_flag;
   };
 
-  /*! 
+
+  /*!
     \relates Sparse_Vec
     \brief Type definition of an integer sparse vector
   */
   typedef Sparse_Vec<int> sparse_ivec;
 
-  /*! 
+  /*!
     \relates Sparse_Vec
     \brief Type definition of a double sparse vector
   */
   typedef Sparse_Vec<double> sparse_vec;
 
-  /*! 
+  /*!
     \relates Sparse_Vec
     \brief Type definition of a complex<double> sparse vector
   */
@@ -398,7 +407,7 @@ namespace itpp {
       eps = v.eps;
       check_small_elems_flag = v.check_small_elems_flag;
       alloc();
-    
+
       for (int i=0; i<used_size; i++) {
 	data[i] = v.data[i];
 	index[i] = v.index[i];
@@ -483,7 +492,7 @@ namespace itpp {
       eps=epsilon;
       remove_small_elements();
     }
- 
+
   template <class T>
     void Sparse_Vec<T>::remove_small_elements()
     {
@@ -515,7 +524,7 @@ namespace itpp {
     void Sparse_Vec<T>::resize_data(int new_size)
     {
       it_assert(new_size>=used_size, "Sparse_Vec<T>::resize_data(int new_size): New size is to small");
-  
+
       if (new_size != data_size) {
 	if (new_size == 0)
 	  free();
@@ -547,7 +556,7 @@ namespace itpp {
     void Sparse_Vec<T>::full(Vec<T> &v) const
     {
       v.set_size(v_size);
-  
+
       v = T(0);
       for (int p=0; p<used_size; p++)
 	v(index[p]) = data[p];
@@ -565,8 +574,8 @@ namespace itpp {
   template <class T>
     T Sparse_Vec<T>::operator()(int i) const
     {
-      it_assert0(i >= 0 && i < v_size, "The index of the element is out of range");
-  
+      it_assert_debug(i >= 0 && i < v_size, "The index of the element is out of range");
+
       bool found = false;
       int p;
       for (p=0; p<used_size; p++) {
@@ -581,8 +590,8 @@ namespace itpp {
   template <class T>
     void Sparse_Vec<T>::set(int i, T v)
     {
-      it_assert0(i >= 0 && i < v_size, "The index of the element is out of range");
-  
+      it_assert_debug(i >= 0 && i < v_size, "The index of the element is out of range");
+
       bool found = false;
       bool larger_than_eps;
       int p;
@@ -616,8 +625,8 @@ namespace itpp {
   template <class T>
     void Sparse_Vec<T>::set_new(int i, T v)
     {
-      it_assert0(v_size > i, "The index of the element exceeds the size of the sparse vector");
-  
+      it_assert_debug(v_size > i, "The index of the element exceeds the size of the sparse vector");
+
       //Check that the new element is larger than eps!
       if (std::abs(v) > std::abs(eps)) {
 	if (used_size == data_size)
@@ -634,8 +643,8 @@ namespace itpp {
       bool found = false;
       int p;
 
-      it_assert0(v_size > i, "The index of the element exceeds the size of the sparse vector");
-  
+      it_assert_debug(v_size > i, "The index of the element exceeds the size of the sparse vector");
+
       for (p=0; p<used_size; p++) {
 	if (index[p] == i) {
 	  found = true;
@@ -663,7 +672,7 @@ namespace itpp {
       int i,p,q;
       int nrof_nz=v.size();
 
-      it_assert0(v_size>max(index_vec),"The indices exceeds the size of the sparse vector");
+      it_assert_debug(v_size>max(index_vec),"The indices exceeds the size of the sparse vector");
 
       //Elements are added if they have identical indices
       for (q=0; q<nrof_nz; q++){
@@ -703,8 +712,8 @@ namespace itpp {
       bool found = false;
       int p;
 
-      it_assert0(v_size > i, "The index of the element exceeds the size of the sparse vector");
-  
+      it_assert_debug(v_size > i, "The index of the element exceeds the size of the sparse vector");
+
       for (p=0; p<used_size; p++) {
 	if (index[p] == i) {
 	  found = true;
@@ -731,8 +740,8 @@ namespace itpp {
       bool found = false;
       int p;
 
-      it_assert0(v_size > i, "The index of the element exceeds the size of the sparse vector");
-  
+      it_assert_debug(v_size > i, "The index of the element exceeds the size of the sparse vector");
+
       for (p=0; p<used_size; p++) {
 	if (index[p] == i) {
 	  found = true;
@@ -749,7 +758,7 @@ namespace itpp {
   template <class T>
     void Sparse_Vec<T>::set(const ivec& index_vec, const Vec<T>& v)
     {
-      it_assert0(v_size>max(index_vec),"The indices exceeds the size of the sparse vector");
+      it_assert_debug(v_size>max(index_vec),"The indices exceeds the size of the sparse vector");
 
       //Clear all old non-zero elements
       clear();
@@ -764,7 +773,7 @@ namespace itpp {
       int q;
       int nrof_nz=v.size();
 
-      it_assert0(v_size>max(index_vec),"The indices exceeds the size of the sparse vector");
+      it_assert_debug(v_size>max(index_vec),"The indices exceeds the size of the sparse vector");
 
       //Clear all old non-zero elements
       clear();
@@ -780,13 +789,24 @@ namespace itpp {
       }
     }
 
+  template <class T>
+  ivec Sparse_Vec<T>::get_nz_indices()
+  {
+    int n = nnz();
+    ivec r(n);
+    for (int i = 0; i < n; i++) {
+      r(i) = get_nz_index(i);
+    }
+    return r;
+  }
+
   template <class T>
     Sparse_Vec<T> Sparse_Vec<T>::get_subvector(int i1, int i2) const
     {
-      it_assert0(v_size > i1 && v_size > i2 && i1<=i2 && i1>=0, "The index of the element exceeds the size of the sparse vector");
-  
+      it_assert_debug(v_size > i1 && v_size > i2 && i1<=i2 && i1>=0, "The index of the element exceeds the size of the sparse vector");
+
       Sparse_Vec<T> r(i2-i1+1);
-  
+
       for (int p=0; p<used_size; p++) {
 	if (index[p] >= i1 && index[p] <= i2) {
 	  if (r.used_size == r.data_size)
@@ -799,7 +819,7 @@ namespace itpp {
       r.eps = eps;
       r.check_small_elems_flag = check_small_elems_flag;
       r.compact();
-  
+
       return r;
     }
 
@@ -809,7 +829,7 @@ namespace itpp {
       T sum(0);
       for (int p=0; p<used_size; p++)
 	sum += data[p] * data[p];
-  
+
       return sum;
     }
 
@@ -823,7 +843,7 @@ namespace itpp {
       eps = v.eps;
       check_small_elems_flag = v.check_small_elems_flag;
       alloc();
-  
+
       for (int i=0; i<used_size; i++) {
 	data[i] = v.data[i];
 	index[i] = v.index[i];
@@ -840,7 +860,7 @@ namespace itpp {
       eps = T(0);
       check_small_elems_flag = false;
       alloc();
-  
+
       for (int i=0; i<v_size; i++) {
 	if (v(i) != T(0)) {
 	  if (used_size == data_size)
@@ -857,13 +877,13 @@ namespace itpp {
     Sparse_Vec<T> Sparse_Vec<T>::operator-() const
     {
       Sparse_Vec r(v_size, used_size);
-  
+
       for (int p=0; p<used_size; p++) {
 	r.data[p] = -data[p];
 	r.index[p] = index[p];
       }
       r.used_size = used_size;
-  
+
       return r;
     }
 
@@ -899,8 +919,8 @@ namespace itpp {
 	    found = false;
 	}
       }
-      
-      /*Special handling if sizes do not match. 
+
+      /*Special handling if sizes do not match.
 	Required since v may need to do remove_small_elements() for true comparison*/
       if (used_size!=v.used_size) {
 	if (used_size > v.used_size) {
@@ -923,7 +943,7 @@ namespace itpp {
       //All elements checks => return true
       return true;
     }
-  
+
   template <class T>
     void Sparse_Vec<T>::operator+=(const Sparse_Vec<T> &v)
     {
@@ -931,8 +951,8 @@ namespace itpp {
       T tmp_data;
       int nrof_nz_v=v.used_size;
 
-      it_assert0(v_size == v.size(), "Attempted addition of unequal sized sparse vectors");
-  
+      it_assert_debug(v_size == v.size(), "Attempted addition of unequal sized sparse vectors");
+
       for (p=0; p<nrof_nz_v; p++) {
 	i = v.index[p];
 	tmp_data = v.data[p];
@@ -948,15 +968,15 @@ namespace itpp {
     {
       int i;
 
-      it_assert0(v_size == v.size(), "Attempted addition of unequal sized sparse vectors");
-  
+      it_assert_debug(v_size == v.size(), "Attempted addition of unequal sized sparse vectors");
+
       for (i=0; i<v.size(); i++)
 	if (v(i)!=T(0))
 	  add_elem(i,v(i));
 
       check_small_elems_flag = true;
     }
-  
+
 
   template <class T>
     void Sparse_Vec<T>::operator-=(const Sparse_Vec<T> &v)
@@ -965,8 +985,8 @@ namespace itpp {
       T tmp_data;
       int nrof_nz_v=v.used_size;
 
-      it_assert0(v_size == v.size(), "Attempted subtraction of unequal sized sparse vectors");
-  
+      it_assert_debug(v_size == v.size(), "Attempted subtraction of unequal sized sparse vectors");
+
       for (p=0; p<nrof_nz_v; p++) {
 	i = v.index[p];
 	tmp_data = v.data[p];
@@ -982,8 +1002,8 @@ namespace itpp {
     {
       int i;
 
-      it_assert0(v_size == v.size(), "Attempted subtraction of unequal sized sparse vectors");
-  
+      it_assert_debug(v_size == v.size(), "Attempted subtraction of unequal sized sparse vectors");
+
       for (i=0; i<v.size(); i++)
 	if (v(i)!=T(0))
 	  add_elem(i,-v(i));
@@ -1008,7 +1028,7 @@ namespace itpp {
       int p;
       for (p=0; p<used_size; p++) {
 	data[p]/=v;}
-      
+
       if (std::abs(eps) > 0) {
 	check_small_elems_flag = true;
       }
@@ -1017,8 +1037,8 @@ namespace itpp {
   template <class T>
     T operator*(const Sparse_Vec<T> &v1, const Sparse_Vec<T> &v2)
     {
-      it_assert0(v1.v_size == v2.v_size, "Sparse_Vec<T> * Sparse_Vec<T>");
-  
+      it_assert_debug(v1.v_size == v2.v_size, "Sparse_Vec<T> * Sparse_Vec<T>");
+
       T sum(0);
       Vec<T> v1f(v1.v_size);
       v1.full(v1f);
@@ -1026,39 +1046,39 @@ namespace itpp {
 	if (v1f[v2.index[p]] != T(0))
 	  sum += v1f[v2.index[p]] * v2.data[p];
       }
-  
+
       return sum;
     }
 
   template <class T>
     T operator*(const Sparse_Vec<T> &v1, const Vec<T> &v2)
     {
-      it_assert0(v1.size() == v2.size(), "Multiplication of unequal sized vectors attempted");
-  
+      it_assert_debug(v1.size() == v2.size(), "Multiplication of unequal sized vectors attempted");
+
       T sum(0);
       for (int p1=0; p1<v1.used_size; p1++)
 	sum += v1.data[p1] * v2[v1.index[p1]];
-  
+
       return sum;
     }
 
   template <class T>
     T operator*(const Vec<T> &v1, const Sparse_Vec<T> &v2)
     {
-      it_assert0(v1.size() == v2.size(), "Multiplication of unequal sized vectors attempted");
-  
+      it_assert_debug(v1.size() == v2.size(), "Multiplication of unequal sized vectors attempted");
+
       T sum(0);
       for (int p2=0; p2<v2.used_size; p2++)
 	sum += v1[v2.index[p2]] * v2.data[p2];
-  
+
       return sum;
     }
 
   template <class T>
     Sparse_Vec<T> elem_mult(const Sparse_Vec<T> &v1, const Sparse_Vec<T> &v2)
     {
-      it_assert0(v1.v_size == v2.v_size, "elem_mult(Sparse_Vec<T>, Sparse_Vec<T>)");
-  
+      it_assert_debug(v1.v_size == v2.v_size, "elem_mult(Sparse_Vec<T>, Sparse_Vec<T>)");
+
       Sparse_Vec<T> r(v1.v_size);
       ivec pos(v1.v_size);
       pos = -1;
@@ -1074,28 +1094,28 @@ namespace itpp {
 	}
       }
       r.compact();
-  
+
       return r;
     }
 
   template <class T>
     Vec<T> elem_mult(const Sparse_Vec<T> &v1, const Vec<T> &v2)
     {
-      it_assert0(v1.v_size == v2.size(), "elem_mult(Sparse_Vec<T>, Vec<T>)");
-  
+      it_assert_debug(v1.v_size == v2.size(), "elem_mult(Sparse_Vec<T>, Vec<T>)");
+
       Vec<T> r(v1.v_size);
       r = T(0);
       for (int p1=0; p1<v1.used_size; p1++)
 	r[v1.index[p1]] = v1.data[p1] * v2[v1.index[p1]];
-  
+
       return r;
     }
 
   template <class T>
     Sparse_Vec<T> elem_mult_s(const Sparse_Vec<T> &v1, const Vec<T> &v2)
     {
-      it_assert0(v1.v_size == v2.size(), "elem_mult(Sparse_Vec<T>, Vec<T>)");
-  
+      it_assert_debug(v1.v_size == v2.size(), "elem_mult(Sparse_Vec<T>, Vec<T>)");
+
       Sparse_Vec<T> r(v1.v_size);
       for (int p1=0; p1<v1.used_size; p1++) {
 	if (v2[v1.index[p1]] != T(0)) {
@@ -1107,28 +1127,28 @@ namespace itpp {
 	}
       }
       r.compact();
-  
+
       return r;
     }
 
   template <class T>
     Vec<T> elem_mult(const Vec<T> &v1, const Sparse_Vec<T> &v2)
     {
-      it_assert0(v1.size() == v2.v_size, "elem_mult(Vec<T>, Sparse_Vec<T>)");
-  
+      it_assert_debug(v1.size() == v2.v_size, "elem_mult(Vec<T>, Sparse_Vec<T>)");
+
       Vec<T> r(v2.v_size);
       r = T(0);
       for (int p2=0; p2<v2.used_size; p2++)
 	r[v2.index[p2]] = v1[v2.index[p2]] * v2.data[p2];
-  
+
       return r;
     }
 
   template <class T>
     Sparse_Vec<T> elem_mult_s(const Vec<T> &v1, const Sparse_Vec<T> &v2)
     {
-      it_assert0(v1.size() == v2.v_size, "elem_mult(Vec<T>, Sparse_Vec<T>)");
-  
+      it_assert_debug(v1.size() == v2.v_size, "elem_mult(Vec<T>, Sparse_Vec<T>)");
+
       Sparse_Vec<T> r(v2.v_size);
       for (int p2=0; p2<v2.used_size; p2++) {
 	if (v1[v2.index[p2]] != T(0)) {
@@ -1140,15 +1160,15 @@ namespace itpp {
 	}
       }
       r.compact();
-  
+
       return r;
     }
 
   template <class T>
     Sparse_Vec<T> operator+(const Sparse_Vec<T> &v1, const Sparse_Vec<T> &v2)
     {
-      it_assert0(v1.v_size == v2.v_size, "Sparse_Vec<T> + Sparse_Vec<T>");
-  
+      it_assert_debug(v1.v_size == v2.v_size, "Sparse_Vec<T> + Sparse_Vec<T>");
+
       Sparse_Vec<T> r(v1);
       ivec pos(v1.v_size);
       pos = -1;
@@ -1165,11 +1185,13 @@ namespace itpp {
 	else
 	  r.data[pos[v2.index[p2]]] += v2.data[p2];
       }
+      r.check_small_elems_flag = true;  // added dec 7, 2006
       r.compact();
-  
+
       return r;
     }
 
+  //! Convert a dense vector \c v into its sparse representation
   template <class T>
     inline Sparse_Vec<T> sparse(const Vec<T> &v)
     {
@@ -1177,6 +1199,7 @@ namespace itpp {
       return s;
     }
 
+  //! Convert a dense vector \c v into its sparse representation
   template <class T>
     inline Sparse_Vec<T> sparse(const Vec<T> &v, T epsilon)
     {
@@ -1184,6 +1207,7 @@ namespace itpp {
       return s;
     }
 
+  //! Convert a sparse vector \c s into its dense representation
   template <class T>
     inline Vec<T> full(const Sparse_Vec<T> &s)
     {
@@ -1192,82 +1216,65 @@ namespace itpp {
       return v;
     }
 
-  /*--------------------------------------------------------------
-   * Explicit initializations
-   *--------------------------------------------------------------*/
-#ifndef _MSC_VER
+  //! \cond
+
+  // ---------------------------------------------------------------------
+  // Instantiations
+  // ---------------------------------------------------------------------
+
+#ifdef HAVE_EXTERN_TEMPLATE
 
-  //! Template instantiation of Sparse_Vec<int>
   extern template class Sparse_Vec<int>;
-  //! Template instantiation of Sparse_Vec<double>
   extern template class Sparse_Vec<double>;
-  //! Template instantiation of Sparse_Vec<complex<double> >
   extern template class Sparse_Vec<std::complex<double> >;
 
+  extern template sparse_ivec operator+(const sparse_ivec &,
+                                        const sparse_ivec &);
+  extern template sparse_vec operator+(const sparse_vec &,
+                                       const sparse_vec &);
+  extern template sparse_cvec operator+(const sparse_cvec &,
+                                        const sparse_cvec &);
 
-  //! Template instantiation of operator+
-  extern template sparse_ivec operator+(const sparse_ivec &, const sparse_ivec &);
-  //! Template instantiation of operator+
-  extern template sparse_vec operator+(const sparse_vec &, const sparse_vec &);
-  //! Template instantiation of operator+
-  extern template sparse_cvec operator+(const sparse_cvec &, const sparse_cvec &);
-
-  //! Template instantiation of operator*
   extern template int operator*(const sparse_ivec &, const sparse_ivec &);
-  //! Template instantiation of operator*
   extern template double operator*(const sparse_vec &, const sparse_vec &);
-  //! Template instantiation of operator*
-  extern template std::complex<double> operator*(const sparse_cvec &, const sparse_cvec &);
+  extern template std::complex<double> operator*(const sparse_cvec &,
+                                                 const sparse_cvec &);
 
-  //! Template instantiation of operator*
   extern template int operator*(const sparse_ivec &, const ivec &);
-  //! Template instantiation of operator*
   extern template double operator*(const sparse_vec &, const vec &);
-  //! Template instantiation of operator*
-  extern template std::complex<double> operator*(const sparse_cvec &, const cvec &);
+  extern template std::complex<double> operator*(const sparse_cvec &,
+                                                 const cvec &);
 
-  //! Template instantiation of operator*
   extern template int operator*(const ivec &, const sparse_ivec &);
-  //! Template instantiation of operator*
   extern template double operator*(const vec &, const sparse_vec &);
-  //! Template instantiation of operator*
-  extern template std::complex<double> operator*(const cvec &, const sparse_cvec &);
+  extern template std::complex<double> operator*(const cvec &,
+                                                 const sparse_cvec &);
 
-  //! Template instantiation of elem_mult
-  extern template sparse_ivec elem_mult(const sparse_ivec &, const sparse_ivec &);
-  //! Template instantiation of elem_mult
+  extern template sparse_ivec elem_mult(const sparse_ivec &,
+                                        const sparse_ivec &);
   extern template sparse_vec elem_mult(const sparse_vec &, const sparse_vec &);
-  //! Template instantiation of elem_mult
-  extern template sparse_cvec elem_mult(const sparse_cvec &, const sparse_cvec &);
+  extern template sparse_cvec elem_mult(const sparse_cvec &,
+                                        const sparse_cvec &);
 
-  //! Template instantiation of elem_mult
   extern template ivec elem_mult(const sparse_ivec &, const ivec &);
-  //! Template instantiation of elem_mult
   extern template vec elem_mult(const sparse_vec &, const vec &);
-  //! Template instantiation of elem_mult
   extern template cvec elem_mult(const sparse_cvec &, const cvec &);
 
-  //! Template instantiation of elem_mult_s
   extern template sparse_ivec elem_mult_s(const sparse_ivec &, const ivec &);
-  //! Template instantiation of elem_mult_s
   extern template sparse_vec elem_mult_s(const sparse_vec &, const vec &);
-  //! Template instantiation of elem_mult_s
   extern template sparse_cvec elem_mult_s(const sparse_cvec &, const cvec &);
 
-  //! Template instantiation of elem_mult
   extern template ivec elem_mult(const ivec &, const sparse_ivec &);
-  //! Template instantiation of elem_mult
   extern template vec elem_mult(const vec &, const sparse_vec &);
-  //! Template instantiation of elem_mult
   extern template cvec elem_mult(const cvec &, const sparse_cvec &);
 
-  //! Template instantiation of elem_mult_s
   extern template sparse_ivec elem_mult_s(const ivec &, const sparse_ivec &);
-  //! Template instantiation of elem_mult_s
   extern template sparse_vec elem_mult_s(const vec &, const sparse_vec &);
-  //! Template instantiation of elem_mult_s
   extern template sparse_cvec elem_mult_s(const cvec &, const sparse_cvec &);
-#endif
+
+#endif // HAVE_EXTERN_TEMPLATE
+
+  //! \endcond
 
 } // namespace itpp
 
