@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Channel Code class virtual interface
  * \author Tony Ottosson
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -45,16 +42,16 @@ namespace itpp {
 
   //---------------------- BCH --------------------------------------
 
-  /*! 
+  /*!
     \ingroup fec
     \brief Generic Channel Code class
-  
+
   */
   class Channel_Code {
   public:
-    //! 
+    //! Default constructor
     Channel_Code() {}
-    //! 
+    //! Destructor
     virtual ~Channel_Code() {}
 
     //! Encode a bvec of input
@@ -75,11 +72,11 @@ namespace itpp {
     virtual bvec decode(const vec &received_signal) = 0;
 
     //! Get the code rate
-    virtual double get_rate() = 0;
+    virtual double get_rate() const = 0;
   };
 
 
-  /*! 
+  /*!
     \ingroup fec
     \brief Dummy Channel Code class
 
@@ -87,9 +84,9 @@ namespace itpp {
   */
   class Dummy_Code : public Channel_Code {
   public:
-    //! 
+    //! Default constructor
     Dummy_Code() {}
-    //! 
+    //! Destructor
     virtual ~Dummy_Code() {}
 
     //! Encode a bvec of input
@@ -108,7 +105,7 @@ namespace itpp {
     virtual bvec decode(const vec &received_signal) { bvec out; decode(received_signal,out); return out; }
 
     //! Get the code rate
-    virtual double get_rate() { return 1.0; }
+    virtual double get_rate() const { return 1.0; }
   };
 
 
