@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Implementation of a binary convolutional encoder class
  * \author Tony Ottosson and Adam Piatyszek
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -32,11 +29,10 @@
 
 #include <itpp/comm/convcode.h>
 #include <itpp/base/binary.h>
-#include <itpp/base/stat.h>
 #include <itpp/base/matfunc.h>
 #include <limits>
 
-namespace itpp { 
+namespace itpp {
 
   // ----------------- Protected functions -----------------------------
 
@@ -63,7 +59,7 @@ namespace itpp {
 
   /*
     The weight (of the reverse code) of the transition from given state with
-    the input given 
+    the input given
   */
   int Convolutional_Code::weight_reverse(const int state, const int input)
   {
@@ -107,7 +103,7 @@ namespace itpp {
 
   /*
     The weight (of the reverse code) of the two paths (input 0 or 1) from
-    given state 
+    given state
   */
   void Convolutional_Code::weight_reverse(const int state, int &w0, int &w1)
   {
@@ -149,7 +145,7 @@ namespace itpp {
   /*
     Output on transition (backwards) with input from state
   */
-  void Convolutional_Code::output_reverse(const int state, bvec &zero_output, 
+  void Convolutional_Code::output_reverse(const int state, bvec &zero_output,
 					  bvec &one_output)
   {
     int j, temp, temp_state;
@@ -168,7 +164,7 @@ namespace itpp {
   /*
     Output on transition (backwards) with input from state
   */
-  void Convolutional_Code::output_reverse(const int state, int &zero_output, 
+  void Convolutional_Code::output_reverse(const int state, int &zero_output,
 					  int &one_output)
   {
     int j, temp, temp_state;
@@ -189,9 +185,9 @@ namespace itpp {
   /*
     Output on transition (backwards) with input from state
   */
-  void Convolutional_Code::calc_metric_reverse(int state, 
-					       const vec &rx_codeword, 
-					       double &zero_metric, 
+  void Convolutional_Code::calc_metric_reverse(int state,
+					       const vec &rx_codeword,
+					       double &zero_metric,
 					       double &one_metric)
   {
     int temp;
@@ -203,16 +199,16 @@ namespace itpp {
       temp = temp_state & gen_pol(j);
       one_bit = temp & 1;
       temp >>= 1;
-      one_metric += (2 * static_cast<int>(xor_int_table(temp) ^ one_bit) - 1) 
+      one_metric += (2 * static_cast<int>(xor_int_table(temp) ^ one_bit) - 1)
 	* rx_codeword(j);
-      zero_metric += (2 * static_cast<int>(xor_int_table(temp)) - 1) 
+      zero_metric += (2 * static_cast<int>(xor_int_table(temp)) - 1)
 	* rx_codeword(j);
     }
   }
 
 
   // calculates metrics for all codewords (2^n of them) in natural order
-  void Convolutional_Code::calc_metric(const vec &rx_codeword, 
+  void Convolutional_Code::calc_metric(const vec &rx_codeword,
 				       vec &delta_metrics)
   {
     int no_outputs = pow2i(n), no_loop = pow2i(n - 1), mask = no_outputs - 1,
@@ -232,7 +228,7 @@ namespace itpp {
 	}
 	delta_metrics(i ^ mask) = -delta_metrics(i); // the inverse codeword
       }
-    } 
+    }
     else {
       double zero_metric, one_metric;
       int zero_output, one_output, temp_state;
@@ -253,9 +249,9 @@ namespace itpp {
 	    zero_metric -= rx_codeword(j);
 	    one_metric += rx_codeword(j);
 	  }
-	  one_output = (one_output << 1) 
+	  one_output = (one_output << 1)
 	    | static_cast<int>(xor_int_table(temp) ^ one_bit);
-	  zero_output = (zero_output << 1) 
+	  zero_output = (zero_output << 1)
 	    | static_cast<int>(xor_int_table(temp));
 	}
 	delta_metrics(zero_output) = zero_metric;
@@ -264,7 +260,7 @@ namespace itpp {
     }
   }
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
+//! \cond
 
   // MFD codes R=1/2
   int Conv_Code_MFD_2[15][2] = {
@@ -529,7 +525,7 @@ namespace itpp {
     }
   }
 
-#endif /* DOXYGEN_SHOULD_SKIP_THIS */
+//! \endcond
 
   // --------------- Public functions -------------------------
 
@@ -551,7 +547,7 @@ namespace itpp {
   /*
     Set generator polynomials. Given in Proakis integer form
   */
-  void Convolutional_Code::set_generator_polynomials(const ivec &gen, 
+  void Convolutional_Code::set_generator_polynomials(const ivec &gen,
 						     int constraint_length)
   {
     it_error_if(constraint_length <= 0, "Convolutional_Code::set_generator_polynomials(): Constraint length out of range");
@@ -613,7 +609,7 @@ namespace itpp {
     trunc_ptr = 0;
     trunc_state = 0;
   }
-  
+
 
   /*
     Encode a binary vector of inputs using specified method
@@ -692,7 +688,7 @@ namespace itpp {
   {
     int temp;
     output.set_size(input.size() * n, false);
-    
+
     // Set the start state equal to the end state:
     encoder_state = 0;
     bvec last_bits = input.right(m);
@@ -734,7 +730,7 @@ namespace itpp {
   void Convolutional_Code::decode(const bvec &coded_bits, bvec &output)
   {
     it_error("Convolutional_Code::decode(): Hard-decision decoding not implemented");
-  } 
+  }
 
   bvec Convolutional_Code::decode(const bvec &coded_bits)
   {
@@ -770,7 +766,7 @@ namespace itpp {
   void Convolutional_Code::decode_tail(const vec &received_signal, bvec &output)
   {
     int block_length = received_signal.size() / n; // no input symbols
-    it_error_if(block_length - m <= 0, 
+    it_error_if(block_length - m <= 0,
 		"Convolutional_Code::decode_tail(): Input sequence to short");
     int S0, S1;
     vec temp_sum_metric(no_states), temp_rec(n), delta_metrics;
@@ -799,25 +795,25 @@ namespace itpp {
 	// S0 and S1 are the states that expanded end at state s
 	previous_state(s, S0, S1);
 	if (visited_state(S0)) { // expand trellis if state S0 is visited
-	  temp_metric_zero = sum_metric(S0) 
+	  temp_metric_zero = sum_metric(S0)
 	    + delta_metrics(output_reverse_int(s, 0));
 	  temp_visited_state(s) = true;
-	} 
+	}
 	else {
 	  temp_metric_zero = std::numeric_limits<double>::max();
 	}
 	if (visited_state(S1)) { // expand trellis if state S0 is visited
-	  temp_metric_one = sum_metric(S1) 
+	  temp_metric_one = sum_metric(S1)
 	    + delta_metrics(output_reverse_int(s, 1));
 	  temp_visited_state(s) = true;
-	} 
+	}
 	else {
 	  temp_metric_one = std::numeric_limits<double>::max();
 	}
 	if (temp_metric_zero < temp_metric_one) { // path zero survives
 	  temp_sum_metric(s) = temp_metric_zero;
 	  path_memory(s, l) = 0;
-	} 
+	}
 	else { // path one survives
 	  temp_sum_metric(s) = temp_metric_one;
 	  path_memory(s, l) = 1;
@@ -837,14 +833,14 @@ namespace itpp {
       for (int s = 0; s < no_states; s++) { // all states
 	// S0 and S1 are the states that expanded end at state s
 	previous_state(s, S0, S1);
-	temp_metric_zero = sum_metric(S0) 
+	temp_metric_zero = sum_metric(S0)
 	  + delta_metrics(output_reverse_int(s, 0));
-	temp_metric_one = sum_metric(S1) 
+	temp_metric_one = sum_metric(S1)
 	  + delta_metrics(output_reverse_int(s, 1));
 	if (temp_metric_zero < temp_metric_one) { // path zero survives
 	  temp_sum_metric(s) = temp_metric_zero;
 	  path_memory(s, l) = 0;
-	} 
+	}
 	else { // path one survives
 	  temp_sum_metric(s) = temp_metric_one;
 	  path_memory(s, l) = 1;
@@ -858,7 +854,7 @@ namespace itpp {
     // trace back to remove tail of zeros
     for (int l = block_length - 1; l > block_length - 1 - m; l--) {
       // previous state calculation
-      min_metric_state = previous_state(min_metric_state, 
+      min_metric_state = previous_state(min_metric_state,
 					path_memory(min_metric_state, l));
     }
 
@@ -866,7 +862,7 @@ namespace itpp {
     for (int l = block_length - 1 - m; l >= 0; l--) {
       output(l) = get_input(min_metric_state);
       // previous state calculation
-      min_metric_state = previous_state(min_metric_state, 
+      min_metric_state = previous_state(min_metric_state,
 					path_memory(min_metric_state, l));
     }
   }
@@ -875,11 +871,11 @@ namespace itpp {
   /*
     Decode a block of encoded data where encode_tailbite has been used.
   */
-  void Convolutional_Code::decode_tailbite(const vec &received_signal, 
+  void Convolutional_Code::decode_tailbite(const vec &received_signal,
 					   bvec &output)
   {
     int block_length = received_signal.size() / n; // no input symbols
-    it_error_if(block_length <= 0, 
+    it_error_if(block_length <= 0,
 		"Convolutional_Code::decode_tailbite(): Input sequence to short");
     int S0, S1;
     vec temp_sum_metric(no_states), temp_rec(n), delta_metrics;
@@ -911,25 +907,25 @@ namespace itpp {
 	  // S0 and S1 are the states that expanded end at state s
 	  previous_state(s, S0, S1);
 	  if (visited_state(S0)) { // expand trellis if state S0 is visited
-	    temp_metric_zero = sum_metric(S0) 
+	    temp_metric_zero = sum_metric(S0)
 	      + delta_metrics(output_reverse_int(s, 0));
 	    temp_visited_state(s) = true;
-	  } 
+	  }
 	  else {
 	    temp_metric_zero = std::numeric_limits<double>::max();
 	  }
 	  if (visited_state(S1)) { // expand trellis if state S0 is visited
-	    temp_metric_one = sum_metric(S1) 
+	    temp_metric_one = sum_metric(S1)
 	      + delta_metrics(output_reverse_int(s, 1));
 	    temp_visited_state(s) = true;
-	  } 
+	  }
 	  else {
 	    temp_metric_one = std::numeric_limits<double>::max();
 	  }
 	  if (temp_metric_zero < temp_metric_one) { // path zero survives
 	    temp_sum_metric(s) = temp_metric_zero;
 	    path_memory(s, l) = 0;
-	  } 
+	  }
 	  else { // path one survives
 	    temp_sum_metric(s) = temp_metric_one;
 	    path_memory(s, l) = 1;
@@ -946,7 +942,7 @@ namespace itpp {
       for (int l = block_length - 1; l >= 0; l--) {
 	temp_output(l) = get_input(min_metric_state);
 	// previous state calculation
-	min_metric_state = previous_state(min_metric_state, 
+	min_metric_state = previous_state(min_metric_state,
 					  path_memory(min_metric_state, l));
       }
       if (sum_metric(ss) < best_metric) {
@@ -961,11 +957,11 @@ namespace itpp {
   /*
     Viterbi decoding using truncation of memory (default = 5*K)
   */
-  void Convolutional_Code::decode_trunc(const vec &received_signal, 
+  void Convolutional_Code::decode_trunc(const vec &received_signal,
 					bvec &output)
   {
     int block_length = received_signal.size() / n; // no input symbols
-    it_error_if(block_length <= 0, 
+    it_error_if(block_length <= 0,
 		"Convolutional_Code::decode_trunc(): Input sequence to short");
     int S0, S1;
     vec temp_sum_metric(no_states), temp_rec(n), delta_metrics;
@@ -979,8 +975,8 @@ namespace itpp {
     temp_visited_state = visited_state;
 
     for (int i = 0; i < block_length; i++) {
-      // updated trunc memory pointer
-      trunc_ptr = ++(trunc_ptr) % trunc_length;
+      // update path memory pointer
+      trunc_ptr = (trunc_ptr + 1) % trunc_length;
 
       temp_rec = received_signal.mid(i * n, n);
       // calculate all metrics for all codewords at the same time
@@ -990,25 +986,25 @@ namespace itpp {
 	// the states that expanded end at state s
 	previous_state(s, S0, S1);
 	if (visited_state(S0)) { // expand trellis if state S0 is visited
-	  temp_metric_zero = sum_metric(S0) 
+	  temp_metric_zero = sum_metric(S0)
 	    + delta_metrics(output_reverse_int(s, 0));
 	  temp_visited_state(s) = true;
-	} 
+	}
 	else {
 	  temp_metric_zero = std::numeric_limits<double>::max();
 	}
 	if (visited_state(S1)) { // expand trellis if state S0 is visited
-	  temp_metric_one = sum_metric(S1) 
+	  temp_metric_one = sum_metric(S1)
 	    + delta_metrics(output_reverse_int(s, 1));
 	  temp_visited_state(s) = true;
-	} 
+	}
 	else {
 	  temp_metric_one = std::numeric_limits<double>::max();
 	}
 	if (temp_metric_zero < temp_metric_one) { // path zero survives
 	  temp_sum_metric(s) = temp_metric_zero;
 	  path_memory(s, trunc_ptr) = 0;
-	} 
+	}
 	else { // path one survives
 	  temp_sum_metric(s) = temp_metric_one;
 	  path_memory(s, trunc_ptr) = 1;
@@ -1028,9 +1024,9 @@ namespace itpp {
 	// trace back to calculate the output symbol
 	for (int j = trunc_length; j > 0; j--) {
 	  // previous state calculation
-	  min_metric_state = 
-	    previous_state(min_metric_state, 
-			   path_memory(min_metric_state, 
+	  min_metric_state =
+	    previous_state(min_metric_state,
+			   path_memory(min_metric_state,
 				       (trunc_ptr + j) % trunc_length));
 	}
 	output.ins(output.size(), get_input(min_metric_state));
@@ -1040,8 +1036,8 @@ namespace itpp {
       }
     } // end for (int i = 0; i < block_length; l++)
   }
-  
-  
+
+
   /*
     Calculate the inverse sequence
 
@@ -1127,7 +1123,6 @@ namespace itpp {
   /*
     Calculate distance profile. If reverse = true calculate for the reverse code instead.
   */
-  //void Convolutional_Code::distance_profile(llvec &dist_prof, int dmax, bool reverse)
   void Convolutional_Code::distance_profile(ivec &dist_prof, int dmax, bool reverse)
   {
     int max_stack_size = 50000;
@@ -1211,15 +1206,11 @@ namespace itpp {
     dmax = an upper bound on the free distance
     no_terms = no_terms including the dmax term that should be calculated
   */
-  //void Convolutional_Code::calculate_spectrum(Array<llvec> &spectrum, int dmax, int no_terms)
   void Convolutional_Code::calculate_spectrum(Array<ivec> &spectrum, int dmax, int no_terms)
   {
     imat Ad_states(no_states, dmax+no_terms), Cd_states(no_states, dmax+no_terms);
     imat Ad_temp(no_states, dmax+no_terms), Cd_temp(no_states, dmax+no_terms);
     ivec mindist(no_states),  mindist_temp(1<<m);
-    //llmat Ad_states(1<<m, dmax+no_terms), Cd_states(1<<m, dmax+no_terms);
-    //llmat Ad_temp(1<<m, dmax+no_terms), Cd_temp(1<<m, dmax+no_terms);
-    //llvec mindist(1<<m),  mindist_temp(1<<m);
 
     spectrum.set_size(2);
     spectrum(0).set_size(dmax+no_terms, false);
@@ -1231,8 +1222,6 @@ namespace itpp {
     mindist.zeros();
     int wmax = dmax+no_terms;
     ivec visited_states(no_states), visited_states_temp(no_states);
-    //long_long wmax = dmax+no_terms;
-    //llvec visited_states(1<<m), visited_states_temp(1<<m);
     bool proceede;
     int d, w0, w1, s, s0, s1;
 
@@ -1299,14 +1288,11 @@ namespace itpp {
     \arg \c no_terms including the dfree term that should be calculated
     \ar \c Cdfree is the best value of information weight spectrum found so far
   */
-  //int Convolutional_Code::fast(Array<llvec> &spectrum, const int dfree, const int no_terms, const int Cdfree, const bool test_catastrophic)
   int Convolutional_Code::fast(Array<ivec> &spectrum, const int dfree, const int no_terms, const int Cdfree, const bool test_catastrophic)
   {
     int cat_treshold = 7*K; // just a big number, but not to big!
     int i;
     ivec dist_prof(K), dist_prof_rev(K);
-    //llvec dist_prof(K), dist_prof_rev(K);
-    //calculate distance profile
     distance_profile(dist_prof, dfree);
     distance_profile(dist_prof_rev, dfree, true); // for the reverse code
 
@@ -1438,7 +1424,7 @@ namespace itpp {
 
   //----------- These functions should be moved into some other place -------
 
-  /*
+  /*!
     Reverses the bitrepresentation of in (of size length) and converts to an integer
   */
   int reverse_int(int length, int in)
@@ -1456,7 +1442,7 @@ namespace itpp {
     return out;
   }
 
-  /*
+  /*!
     Calculate the Hamming weight of the binary representation of in of size length
   */
   int weight_int(int length, int in)
@@ -1468,14 +1454,12 @@ namespace itpp {
     return w;
   }
 
-  /*
-    \relates Convolutional_Code
+  /*!
     Compare two distance spectra. Return 1 if v1 is less, 0 if v2 less, and -1 if equal.
   */
-  //int compare_spectra(llvec v1, llvec v2)
   int compare_spectra(ivec v1, ivec v2)
   {
-    it_assert1(v1.size() == v2.size(), "compare_spectra: wrong sizes");
+    it_assert_debug(v1.size() == v2.size(), "compare_spectra: wrong sizes");
 
     for (int i=0; i<v1.size(); i++) {
       if (v1(i) < v2(i)) {
@@ -1487,7 +1471,7 @@ namespace itpp {
     return -1;
   }
 
-  /*
+  /*!
     Compare two distance spectra using a weight profile.
 
     Return 1 if v1 is less, 0 if v2 less, and -1 if equal.
