@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Definition of a CRC code class
  * \author Tony Ottosson
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -39,8 +36,8 @@
 
 namespace itpp {
 
-  /*! 
-    \ingroup fec 
+  /*!
+    \ingroup fec
     \brief Cyclic Redundancy Check Codes
 
     This class will add the CRC bits after each input word. With b(i)
@@ -70,8 +67,8 @@ namespace itpp {
     //! Default Constructor
     CRC_Code() { reverse_parity = false; }
 
-    /*! 
-      \brief Set CRC code to one of the standardpolynomials using the 
+    /*!
+      \brief Set CRC code to one of the standardpolynomials using the
 			string value.
       \param code Possible values: CRC-4, CRC-7, CRC-8, CRC-12,
       CRC-24, CRC-32, CCITT-4, CCITT-5, CCITT-6, CCITT-16, CCITT-32,
@@ -86,22 +83,22 @@ namespace itpp {
     void set_code(const std::string &code);
 
     //! Calulate the parity bits
-    void parity(const bvec &in_bits, bvec &out);
+    void parity(const bvec &in_bits, bvec &out) const;
 
     //! Return true if parity checks OK otherwise flase
-    bool check_parity(const bvec &coded_bits);
+    bool check_parity(const bvec &coded_bits) const;
 
     //! Calculate and add parity to the in_bits.
-    void encode(const bvec &in_bits, bvec &out);
+    void encode(const bvec &in_bits, bvec &out) const;
 
     //! Returns the in_bits vector with parity added
-    bvec encode(const bvec &in_bits);
+    bvec encode(const bvec &in_bits) const;
 
-    //! Return true if parity checks OK otherwise flase. Also returns the message part in out. 
-    bool decode(const bvec &coded_bits, bvec &out);
+    //! Return true if parity checks OK otherwise flase. Also returns the message part in out.
+    bool decode(const bvec &coded_bits, bvec &out) const;
 
     //! Return true if parity checks OK otherwise flase. Also returns the message part in bits.
-    bool decode(bvec &bits);
+    bool decode(bvec &bits) const;
 
   private:
     bool reverse_parity;
