@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Implementation of the Extended Golay Code (24, 12, 8)
  * \author Tony Ottosson
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -32,12 +29,13 @@
 
 #include <itpp/comm/egolay.h>
 #include <itpp/comm/commfunc.h>
+#include <itpp/base/specmat.h>
+#include <itpp/base/converters.h>
 
-
-namespace itpp { 
+namespace itpp {
 
   Extended_Golay::Extended_Golay(void)
-  {	
+  {
     B="0 1 1 1 1 1 1 1 1 1 1 1;1 1 1 0 1 1 1 0 0 0 1 0;1 1 0 1 1 1 0 0 0 1 0 1;1 0 1 1 1 0 0 0 1 0 1 1;1 1 1 1 0 0 0 1 0 1 1 0;1 1 1 0 0 0 1 0 1 1 0 1;1 1 0 0 0 1 0 1 1 0 1 1;1 0 0 0 1 0 1 1 0 1 1 1;1 0 0 1 0 1 1 0 1 1 1 0;1 0 1 0 1 1 0 1 1 1 0 0;1 1 0 1 1 0 1 1 1 0 0 0;1 0 1 1 0 1 1 1 0 0 0 1";
 
     G = concat_horizontal(eye_b(12), B);
@@ -46,13 +44,13 @@ namespace itpp {
   void Extended_Golay::encode(const bvec &uncoded_bits, bvec &coded_bits)
   {
     int no_bits = uncoded_bits.length();
-    int no_blocks = (int)floor((double)no_bits/12);
-    
+    int no_blocks = floor_i(no_bits / 12.0);
+
     coded_bits.set_size(24*no_blocks, false);
     bmat Gt = G.T();
     int i;
-	
-    for (i=0; i<no_blocks; i++) 
+
+    for (i=0; i<no_blocks; i++)
       coded_bits.replace_mid(24*i, Gt * uncoded_bits.mid(i*12,12));
   }
 
@@ -66,8 +64,8 @@ namespace itpp {
   void Extended_Golay::decode(const bvec &coded_bits, bvec &decoded_bits)
   {
     int no_bits = coded_bits.length();
-    int no_blocks = (int)floor((double)no_bits/24);
-    
+    int no_blocks = floor_i(no_bits / 24.0);
+
     decoded_bits.set_size(12*no_blocks, false);
     int i, j;
     bvec S(12),BS(12),r(12),temp(12),e(24),c(24);
@@ -81,10 +79,10 @@ namespace itpp {
       if( weight(S) <= 3 ) {
 				e = concat(S, zeros_b(12)); goto Step8;
       }
-	  
+
       // Step 3. w(S+Ii)<=2. e=(S+Ii,yi). Goto 8.
       for (j=0; j<12; j++) {
-			
+
 				temp = S + B.get_col(j);
 				if ( weight(temp) <=2 ) {
 					e = concat(temp, eyetemp.get_row(j)); goto Step8;
@@ -109,11 +107,11 @@ namespace itpp {
 
       // Step 7. Uncorrectable erreor pattern. Choose the first 12 bits.
       e = zeros_b(24); goto Step8;
-	  
+
     Step8: // Step 8. c=r+e. STOP
       c = r + e;
       decoded_bits.replace_mid(i*12, c.left(12));
-    }  
+    }
   }
 
   bvec Extended_Golay::decode(const bvec &coded_bits)
