@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Definition of the Extended Golay Code (24, 12, 8)
  * \author Tony Ottosson
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -40,11 +37,11 @@
 
 namespace itpp {
 
-  /*! 
+  /*!
     \ingroup fec
     \brief Extended Golay code (24,12,8).
     \author Tony Ottosson
-  
+
     The code is given in systematic form with the information bits
     first, followed by the parity check bits. The decoder uses the
     arithmetic decoding algorithm that is for example described in
@@ -73,10 +70,10 @@ namespace itpp {
     virtual bvec decode(const vec &received_signal);
 
     //! Get the code rate
-    virtual double get_rate() { return 0.5; };
+    virtual double get_rate() const { return 0.5; };
 
     //! Gets the generator matrix for the code (also the parity check matrix)
-    bmat get_G() { return G; }
+    bmat get_G() const { return G; }
   private:
     bmat B,G;
   };
