@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Definitions of interleaver classes
  * \author Pal Frenger
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -33,6 +30,12 @@
 #ifndef INTERLEAVE_H
 #define INTERLEAVE_H
 
+#ifndef _MSC_VER
+#  include <itpp/config.h>
+#else
+#  include <itpp/config_msvc.h>
+#endif
+
 #include <itpp/base/vec.h>
 #include <itpp/base/mat.h>
 #include <itpp/base/random.h>
@@ -47,7 +50,7 @@ namespace itpp {
   /*! \ingroup interl
     \class Block_Interleaver comm/interleave.h
     \brief Block Interleaver Class.
-  
+
     Data is written row-wise and read column-wise when interleaving.
     <h3>Example of use:</h3>
     \code
@@ -58,7 +61,7 @@ namespace itpp {
     Block_Interleaver<double> block_interleaver(4,4);
     vec interleaved_symbols = block_interleaver.interleave(symbols);
     \endcode
-  
+
   */
   template <class T>
     class Block_Interleaver {
@@ -81,7 +84,7 @@ namespace itpp {
     void set_cols(int in_cols) {cols = in_cols;};
     //! Get the number of \a rows for block interleaving
     int get_rows(void) {return rows;};
-    //! Get the number of \a columns for block interleaving    
+    //! Get the number of \a columns for block interleaving
     int get_cols(void) {return cols;};
     private:
     int rows, cols, input_length;
@@ -100,7 +103,7 @@ namespace itpp {
     Cross_Interleaver<double> cross_interleaver(4);
     vec interleaved_symbols = cross_interleaver.interleave(symbols);
     \endcode
-  
+
     <ul>
     <li> See S. B. Wicker, "Error control systems for digital communications and storage,"
     Prentice Hall 1995, p. 427 for details. </li>
@@ -122,7 +125,7 @@ namespace itpp {
     //! Function for cross deinterleaving. Removes aditional zeros if \a keepzeros = 0.
     void deinterleave(const Vec<T> &input, Vec<T> &output, short keepzeros = 0);
     //! Set the \a order of the Cross Interleaver
-    void set_order(int in_order); 
+    void set_order(int in_order);
     //! Get the \a order of the Cross Interleaver
     int get_order(void) {return order;};
     private:
@@ -146,20 +149,20 @@ namespace itpp {
     sequence_interleaver.randomize_interleaver_sequence();
     vec interleaved_symbols = sequence_snterleaver.interleave(symbols);
     \endcode
-  
+
   */
   template <class T>
     class Sequence_Interleaver {
     public:
     //! Sequence_Interleaver constructor.
     Sequence_Interleaver(void) {interleaver_depth = 0;};
-    /*! 
+    /*!
       \brief Sequence_Interleaver constructor.
 
       Chooses a random sequence of length \a in_interleaver_depth for interleaving.
     */
     Sequence_Interleaver(int in_interleaver_depth);
-    /*! 
+    /*!
       \brief Sequence_Interleaver constructor.
 
       Uses the \a in_interleaver_sequence for interleaving.
@@ -475,12 +478,8 @@ namespace itpp {
       int thisinput_length = input.length();
       int steps = (int)std::ceil( double(thisinput_length)/double(interleaver_depth) );
       int output_length = steps*interleaver_depth;
-      //long_long thisinput_length = input.length();
-      //long_long steps = (long_long)std::ceil( double(thisinput_length)/double(interleaver_depth) );
-      //long_long output_length = steps*interleaver_depth;
       output.set_length(output_length,false);
       int	s, i;
-      //long_long	s, i;
 
       if (thisinput_length == output_length) {
 
@@ -535,45 +534,38 @@ namespace itpp {
     void Sequence_Interleaver<T>::set_interleaver_sequence(ivec in_interleaver_sequence)
     {
       interleaver_sequence = in_interleaver_sequence;
-      interleaver_depth = interleaver_sequence.size(); 
+      interleaver_depth = interleaver_sequence.size();
     }
 
-  // ------------------------ Instantiations --------------------------------
-#ifndef _MSC_VER
+  //! \cond
+
+  // ----------------------------------------------------------------------
+  // Instantiations
+  // ----------------------------------------------------------------------
+
+#ifdef HAVE_EXTERN_TEMPLATE
 
-  //! Template instantiation of Block_Interleaver
   extern template class Block_Interleaver<double>;
-  //! Template instantiation of Block_Interleaver
   extern template class Block_Interleaver<short>;
-  //! Template instantiation of Block_Interleaver
   extern template class Block_Interleaver<int>;
-  //! Template instantiation of Block_Interleaver
   extern template class Block_Interleaver<std::complex<double> >;
-  //! Template instantiation of Block_Interleaver
   extern template class Block_Interleaver<bin>;
 
-  //! Template instantiation of Cross_Interleaver
   extern template class Cross_Interleaver<double>;
-  //! Template instantiation of Cross_Interleaver
   extern template class Cross_Interleaver<short>;
-  //! Template instantiation of Cross_Interleaver
   extern template class Cross_Interleaver<int>;
-  //! Template instantiation of Cross_Interleaver
   extern template class Cross_Interleaver<std::complex<double> >;
-  //! Template instantiation of Cross_Interleaver
   extern template class Cross_Interleaver<bin>;
 
-  //! Template instantiation of Sequence_Interleaver
   extern template class Sequence_Interleaver<double>;
-  //! Template instantiation of Sequence_Interleaver
   extern template class Sequence_Interleaver<short>;
-  //! Template instantiation of Sequence_Interleaver
   extern template class Sequence_Interleaver<int>;
-  //! Template instantiation of Sequence_Interleaver
   extern template class Sequence_Interleaver<std::complex<double> >;
-  //! Template instantiation of Sequence_Interleaver
   extern template class Sequence_Interleaver<bin>;
-#endif
+
+#endif // HAVE_EXTERN_TEMPLATE
+
+  //! \endcond
 
 } // namespace itpp
 
