@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Definitions of a Binary Punctured Convolutional Encoder class
  * \author Tony Ottosson
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -99,10 +96,10 @@ namespace itpp {
     void set_generator_polynomials(const ivec &gen, int constraint_length)
       { Convolutional_Code::set_generator_polynomials(gen, constraint_length); }
     //! Get generator polynomials
-    ivec get_generator_polynomials(void) { return gen_pol; }
+    ivec get_generator_polynomials() const { return gen_pol; }
 
     //! Return rate of code
-    virtual double get_rate(void) { return rate; }
+    virtual double get_rate() const { return rate; }
 
     //! Set encoding and decoding method (Trunc, Tail, or Tailbite)
     void set_method(const CONVOLUTIONAL_CODE_METHOD method) { Convolutional_Code::set_method(method); }
@@ -110,9 +107,9 @@ namespace itpp {
     //! Set puncture matrix (size n*Period)
     void set_puncture_matrix(const bmat &pmatrix); // add test of matrix size
     //! Get puncture matrix
-    bmat get_puncture_matrix(void) { return puncture_matrix; }
+    bmat get_puncture_matrix() const { return puncture_matrix; }
     //! Get puncturing period
-    int get_puncture_period(void) { return Period; }
+    int get_puncture_period() const { return Period; }
 
     //! Set the encoder internal state in start_state (set by set_start_state()).
     void init_encoder() { encoder_state = start_state; }
@@ -199,7 +196,6 @@ namespace itpp {
 
     //! Calculate distance profile. If reverse = true calculate for the reverse code instead.
     void distance_profile(ivec &dist_prof, int time, int dmax = 100000, bool reverse = false);
-    //void distance_profile(llvec &dist_prof, int time, int dmax = 100000, bool reverse = false);
 
     /*!
       \brief Calculate spectrum.
@@ -218,10 +214,6 @@ namespace itpp {
       Observe that there is a risk that some of the integers are overflow if many terms are calculated in the spectrum.
     */
     void calculate_spectrum(Array<ivec> &spectrum, int dmax, int no_terms);
-    //void calculate_spectrum(Array<llvec> &spectrum, int dmax, int no_terms);
-
-    // Calculate spectrum. Suitable when calculating many terms in the spectra. Breadth first search.
-    // void calculate_spectrum(Array<llvec> &spectrum, int time, int dmax, int no_terms);
 
     /*!
       \brief Calculate spectrum. Suitable when calculating many terms in the spectra. Breadth first search.
@@ -234,7 +226,6 @@ namespace itpp {
       </ul>
     */
     void calculate_spectrum(Array<ivec> &spectrum, int time, int dmax, int no_terms, int block_length=0);
-    //void calculate_spectrum(Array<llvec> &spectrum, int time, int dmax, int no_terms, int block_length=0);
 
     /*!
       \brief Cederwall's fast algorithm.
@@ -253,7 +244,6 @@ namespace itpp {
       Observe that there is a risk that some of the integers are overflow if many terms are calculated in the spectrum.
     */
     int fast(Array<ivec> &spectrum, int time, int dfree, int no_terms, int d_best_so_far = 0, bool test_catastrophic = false);
-    //int fast(Array<llvec> &spectrum, int time, int dfree, int no_terms, int d_best_so_far = 0, bool test_catastrophic = false);
 
   protected:
     //! The weight of path from \c state with \c input (0 or 1) at transition \c time
