@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Implementation of a turbo encoder/decoder class
  * \author Pal Frenger. QLLR support by Erik G. Larsson.
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -33,10 +30,10 @@
 #include <itpp/comm/turbo.h>
 
 
-namespace itpp { 
+namespace itpp {
 
   void Turbo_Codec::set_parameters(ivec gen1, ivec gen2, int constraint_length, const ivec &interleaver_sequence,
-				   int in_iterations, std::string in_metric, double in_logmax_scale_factor, 
+				   int in_iterations, std::string in_metric, double in_logmax_scale_factor,
 				   bool in_adaptive_stop,  LLR_calc_unit in_llrcalc)
   {
     //Set the input parameters:
@@ -74,7 +71,7 @@ namespace itpp {
     m_tail = constraint_length - 1;
 
     //Calculate the number of coded bits per code-block:
-    Ncoded = Nuncoded * n_tot + m_tail * (1 + n1) + m_tail * (1 + n2); 
+    Ncoded = Nuncoded * n_tot + m_tail * (1 + n1) + m_tail * (1 + n2);
 
     //Set the interleaver sequence
     bit_interleaver.set_interleaver_depth(interleaver_size);
@@ -85,7 +82,7 @@ namespace itpp {
     //Default value of the channel reliability scaling factor is 1
     Lc = 1.0;
 
-    // LLR algebra table   
+    // LLR algebra table
     rscc1.set_llrcalc(in_llrcalc);
     rscc2.set_llrcalc(in_llrcalc);
 
@@ -97,8 +94,8 @@ namespace itpp {
     Nuncoded = interleaver_size;
 
     //Calculate the number of coded bits per code-block:
-    Ncoded = Nuncoded * n_tot + m_tail * (1 + n1) + m_tail * (1 + n2); 
-  
+    Ncoded = Nuncoded * n_tot + m_tail * (1 + n1) + m_tail * (1 + n2);
+
     //Set the interleaver sequence
     bit_interleaver.set_interleaver_depth(interleaver_size);
     float_interleaver.set_interleaver_depth(interleaver_size);
@@ -109,7 +106,7 @@ namespace itpp {
   void Turbo_Codec::set_metric(std::string in_metric, double in_logmax_scale_factor, LLR_calc_unit in_llrcalc)
   {
     logmax_scale_factor = in_logmax_scale_factor;
-  
+
     //Check the decoding metric
     if (in_metric=="LOGMAX") {
       metric = "LOGMAX";
@@ -141,7 +138,7 @@ namespace itpp {
   {
     Ec = in_Ec;
     N0 = in_N0;
-    Lc = 4.0*sqrt(Ec)/N0;
+    Lc = 4.0 * std::sqrt(Ec)/N0;
   }
 
   void Turbo_Codec::set_scaling_factor(double in_Lc)
@@ -150,35 +147,35 @@ namespace itpp {
   }
 
 
-  void Turbo_Codec::encode(const bvec &input, bvec &output) 
+  void Turbo_Codec::encode(const bvec &input, bvec &output)
   {
     //Local variables:
     int i, k, j, no_blocks;
-    long count;
+    int count;
     bvec input_bits, in1, in2, tail1, tail2, out;
     bmat parity1, parity2;
-  
+
     //Initializations:
     no_blocks = input.length() / Nuncoded;
     output.set_size(no_blocks*Ncoded,false);
-  
+
     //Set the bit counter to zero:
     count = 0;
 
     //Encode all code blocks:
     for (i=0; i<no_blocks; i++) {
-    
+
       //Encode one block
       input_bits = input.mid(i*Nuncoded,Nuncoded);
       encode_block(input_bits, in1, in2, parity1, parity2);
-    
+
       //The data part:
       for (k=0; k<Nuncoded; k++) {
 	output(count) = in1(k); count++;                                //Systematic bits
 	for (j=0; j<n1; j++) { output(count) = parity1(k,j); count++; } //Parity-1 bits
 	for (j=0; j<n2; j++) { output(count) = parity2(k,j); count++; } //Parity-2 bits
       }
-    
+
       //The first tail:
       for (k=0; k<m_tail; k++) {
 	output(count) = in1(Nuncoded+k); count++;                                //First systematic tail bit
@@ -191,8 +188,8 @@ namespace itpp {
 	for (j=0; j<n2; j++) { output(count) = parity2(Nuncoded+k,j); count++; } //Parity-2 tail bits
       }
 
-    } 
-  
+    }
+
   }
 
   void Turbo_Codec::decode(const vec &received_signal, bvec &decoded_bits, const bvec &true_bits)
@@ -201,7 +198,7 @@ namespace itpp {
     decode(received_signal, decoded_bits, nrof_used_iterations, true_bits);
   }
 
-  void Turbo_Codec::decode(const vec &received_signal, bvec &decoded_bits, ivec &nrof_used_iterations, 
+  void Turbo_Codec::decode(const vec &received_signal, bvec &decoded_bits, ivec &nrof_used_iterations,
 			   const bvec &true_bits)
   {
 
@@ -215,17 +212,17 @@ namespace itpp {
       mat rec_parity1, rec_parity2;
       bmat decoded_bits_i;
       int no_blocks, i, j, k, nrof_used_iterations_i;
-      long count;
+      int count;
       bool CHECK_TRUE_BITS;
-    
+
       //Initilaizations:
       no_blocks = received_signal.length() / Ncoded;
       decoded_bits.set_size(no_blocks * Nuncoded, false);
       decoded_bits_i.set_size(iterations, no_blocks * Nuncoded, false);
       rec_syst1.set_size(Nuncoded+m_tail,false);
       rec_syst2.set_size(Nuncoded+m_tail,false); rec_syst2.clear();
-      rec_parity1.set_size(Nuncoded+m_tail,n1,false); 
-      rec_parity2.set_size(Nuncoded+m_tail,n2,false); 
+      rec_parity1.set_size(Nuncoded+m_tail,n1,false);
+      rec_parity2.set_size(Nuncoded+m_tail,n2,false);
       nrof_used_iterations.set_size(no_blocks, false);
 
       //Check the vector true_bits:
@@ -235,32 +232,32 @@ namespace itpp {
       } else {
 	CHECK_TRUE_BITS = false;
       }
-    
+
       //Set the bit counter to zero:
       count = 0;
-    
+
       //Itterate over all received code blocks:
       for (i=0; i<no_blocks; i++) {
-      
+
 	//The data part:
 	for (k=0; k<Nuncoded; k++) {
 	  rec_syst1(k) = received_signal(count); count++;                               //Systematic bit
 	  for (j=0; j<n1; j++) { rec_parity1(k,j) = received_signal(count); count++; }  //Parity-1 bits
 	  for (j=0; j<n2; j++) { rec_parity2(k,j) = received_signal(count); count++; }  //Parity-2 bits
 	}
-      
+
 	//The first tail:
 	for (k=0; k<m_tail; k++) {
 	  rec_syst1(Nuncoded+k) = received_signal(count); count++;                               //Tail 1 systematic bit
 	  for (j=0; j<n1; j++) { rec_parity1(Nuncoded+k,j) = received_signal(count); count++; }  //Tail 1 parity-1 bits
 	}
-      
+
 	//The second tail:
 	for (k=0; k<m_tail; k++) {
 	  rec_syst2(Nuncoded+k) = received_signal(count); count++;                              //Tail2 systematic bit
 	  for (j=0; j<n2; j++) { rec_parity2(Nuncoded+k,j) = received_signal(count); count++; } //Tali2 parity-2 bits
 	}
-      
+
 	//Scale the input data if necessary:
 	if (Lc != 1.0) {
 	  rec_syst1 *= Lc;
@@ -268,20 +265,20 @@ namespace itpp {
 	  rec_parity1 *= Lc;
 	  rec_parity2 *= Lc;
 	}
-      
+
 	//Decode the block:
 	if (CHECK_TRUE_BITS) {
-	  decode_block(rec_syst1, rec_syst2, rec_parity1, rec_parity2, decoded_bits_i, 
+	  decode_block(rec_syst1, rec_syst2, rec_parity1, rec_parity2, decoded_bits_i,
 		       nrof_used_iterations_i, true_bits.mid(i*Nuncoded,Nuncoded) );
 	  nrof_used_iterations(i) = nrof_used_iterations_i;
 	} else {
 	  decode_block(rec_syst1, rec_syst2, rec_parity1, rec_parity2, decoded_bits_i, nrof_used_iterations_i);
 	  nrof_used_iterations(i) = nrof_used_iterations_i;
 	}
-      
+
 	//Put the decoded bits in the output vector:
-	decoded_bits.replace_mid(i*Nuncoded, decoded_bits_i.get_row(iterations-1)); 
-      
+	decoded_bits.replace_mid(i*Nuncoded, decoded_bits_i.get_row(iterations-1));
+
       }
 
     }
@@ -307,7 +304,7 @@ namespace itpp {
     rscc1.encode_tail(input, tail1, parity1);
 
     //The interleaver:
-    bit_interleaver.interleave(input,interleaved_input); 
+    bit_interleaver.interleave(input,interleaved_input);
 
     //The second encoder:
     rscc2.encode_tail(interleaved_input, tail2, parity2);
@@ -315,33 +312,33 @@ namespace itpp {
     //The input vectors used to the two constituent encoders:
     in1 = concat(input,tail1);
     in2 = concat(interleaved_input,tail2);
-  
+
   }
 
-  void Turbo_Codec::decode_block(const vec &rec_syst1, const vec &rec_syst2, const mat &rec_parity1, 
-				 const mat &rec_parity2, bmat &decoded_bits_i, int &nrof_used_iterations_i, 
+  void Turbo_Codec::decode_block(const vec &rec_syst1, const vec &rec_syst2, const mat &rec_parity1,
+				 const mat &rec_parity2, bmat &decoded_bits_i, int &nrof_used_iterations_i,
 				 const bvec &true_bits)
   {
     //Local variables:
     int i;
-    long count, l, k;
+    int count, l, k;
     vec extrinsic_input, extrinsic_output, int_rec_syst1, int_rec_syst, tmp;
     vec deint_rec_syst2, rec_syst, sub_rec_syst, Le12, Le21, Le12_int, Le21_int, L, tail1, tail2;
-    bool CHECK_TRUE_BITS, CONTINUE; 
+    bool CHECK_TRUE_BITS, CONTINUE;
 
     //Size initializations:
-    decoded_bits_i.set_size(iterations, Nuncoded, false); 
+    decoded_bits_i.set_size(iterations, Nuncoded, false);
     Le12.set_size(Nuncoded+m_tail, false);
     Le21.set_size(Nuncoded+m_tail, false); Le21.zeros();
 
     //Calculate the interleaved and the deinterleaved sequences:
     float_interleaver.interleave(rec_syst1.left(interleaver_size),int_rec_syst1);
     float_interleaver.deinterleave(rec_syst2.left(interleaver_size),deint_rec_syst2);
-  
+
     //Combine the results from rec_syst1 and rec_syst2 (in case some bits are transmitted several times)
     rec_syst = rec_syst1.left(interleaver_size) + deint_rec_syst2;
     int_rec_syst = rec_syst2.left(interleaver_size) + int_rec_syst1;
-  
+
     //Get the two tails
     tail1 = rec_syst1.right(m_tail);
     tail2 = rec_syst2.right(m_tail);
@@ -349,7 +346,7 @@ namespace itpp {
     //Form the input vectors (including tails) to the two decoders:
     rec_syst = concat(rec_syst,tail1);
     int_rec_syst = concat(int_rec_syst,tail2);
-  
+
     // Check the vector true_bits
     if (true_bits.size()>1) {
       it_assert(true_bits.size()==Nuncoded,"Turbo_Codec::decode_block: Illegal size of input vector true_bits");
@@ -397,7 +394,7 @@ namespace itpp {
 
       // De-interleave the extrinsic information:
       float_interleaver.deinterleave(Le21_int.left(interleaver_size),tmp);
-      Le21 = concat(tmp,zeros(Le21_int.size()-interleaver_size));  
+      Le21 = concat(tmp,zeros(Le21_int.size()-interleaver_size));
 
       // Take bit decisions
       L = rec_syst + Le21 + Le12;
@@ -406,23 +403,23 @@ namespace itpp {
 	(L(l)>0.0) ? (decoded_bits_i(i,count) = bin(0)) : (decoded_bits_i(i,count) = bin(1));
 	count++;
       }
- 
+
       //Check if it is possible to stop iterating early:
       CONTINUE = true;
       if (i<(iterations-1)) {
-      
+
 	if (CHECK_TRUE_BITS) {
 	  CONTINUE = false;
 	  for (k=0; k<Nuncoded; k++) { if (true_bits(k) != decoded_bits_i(i,k)) { CONTINUE = true; break; } }
-	} 
-      
+	}
+
 	if ((adaptive_stop) && (i>0)) {
 	  CONTINUE = false;
 	  for (k=0; k<Nuncoded; k++) { if (decoded_bits_i(i-1,k) != decoded_bits_i(i,k)) { CONTINUE = true; break; } }
 	}
-	
+
       }
-      
+
       //Check if iterations shall continue:
       if (CONTINUE==false) {
 	//Copy the results from current iteration to all following iterations:
@@ -434,10 +431,10 @@ namespace itpp {
       }
 
     }
-  
+
   }
 
-  void Turbo_Codec::decode_n3(const vec &received_signal, bvec &decoded_bits, ivec &nrof_used_iterations, 
+  void Turbo_Codec::decode_n3(const vec &received_signal, bvec &decoded_bits, ivec &nrof_used_iterations,
 			      const bvec &true_bits)
   {
     //Local variables:
@@ -446,7 +443,7 @@ namespace itpp {
     vec extrinsic_input, extrinsic_output, Le12, Le21, Le12_int, Le21_int, L;
     bvec temp_decoded_bits;
     int no_blocks, i, j, k, l, nrof_used_iterations_i;
-    long count, count_out;
+    int count, count_out;
     bool CHECK_TRUE_BITS, CONTINUE;
 
     //Initializations:
@@ -454,8 +451,8 @@ namespace itpp {
     decoded_bits.set_size(no_blocks * Nuncoded, false);
     rec_syst1.set_size(Nuncoded+m_tail,false);
     rec_syst2.set_size(Nuncoded+m_tail,false); rec_syst2.clear();
-    rec_parity1.set_size(Nuncoded+m_tail,false); 
-    rec_parity2.set_size(Nuncoded+m_tail,false); 
+    rec_parity1.set_size(Nuncoded+m_tail,false);
+    rec_parity2.set_size(Nuncoded+m_tail,false);
     temp_decoded_bits.set_size(Nuncoded,false);
     decoded_bits_previous_iteration.set_size(Nuncoded,false);
     nrof_used_iterations.set_size(no_blocks, false);
@@ -505,7 +502,7 @@ namespace itpp {
 	rec_syst2(Nuncoded+k)   = received_signal(count); count++; //Tail2 systematic bit
 	rec_parity2(Nuncoded+k) = received_signal(count); count++; //Tali2 parity-2 bits
       }
-    
+
       float_interleaver.interleave(rec_syst1.left(Nuncoded),int_rec_syst1);
       rec_syst2.replace_mid(0,int_rec_syst1);
 
@@ -549,17 +546,17 @@ namespace itpp {
 	    CONTINUE = false;
 	  }
 	}
-	
+
 	if (CONTINUE==false) { nrof_used_iterations_i = j+1; break; }
 
       }
-      
+
       //Take final bit decisions
       L = rec_syst1.left(Nuncoded) + Le21.left(Nuncoded) + Le12.left(Nuncoded);
-      for (l=0; l<Nuncoded; l++) { 
-	(L(l)>0.0) ? (decoded_bits(count_out) = bin(0)) : (decoded_bits(count_out) = bin(1)); count_out++; 
+      for (l=0; l<Nuncoded; l++) {
+	(L(l)>0.0) ? (decoded_bits(count_out) = bin(0)) : (decoded_bits(count_out) = bin(1)); count_out++;
       }
-    
+
       nrof_used_iterations(i) = nrof_used_iterations_i;
 
     }
@@ -583,12 +580,12 @@ namespace itpp {
     ivec I; //The interleaver sequence
     ivec primes, roots, Pat1, Pat2, Pat3, Pat4, Isort;
     int i, j, qj, temp, row, col, index, count;
-  
+
     if (interleaver_size > MAX_INTERLEAVER_SIZE) {
 
       I = sort_index(randu(interleaver_size));
       return I;
-  
+
     } else {
 
       p = 0;
@@ -597,13 +594,13 @@ namespace itpp {
       //Check the range of the interleaver size:
       it_assert(interleaver_size <= MAX_INTERLEAVER_SIZE,"wcdma_turbo_interleaver_sequence: The interleaver size is to large");
       it_assert(interleaver_size >= MIN_INTERLEAVER_SIZE,"wcdma_turbo_interleaver_sequence: The interleaver size is to small");
-    
+
       K = interleaver_size;
-    
+
       //Definitions of primes and associated primitive roots:
       primes = "2 3 5 7 11 13 17 19 23 29 31 37 41 43 47 53 59 61 67 71 73 79 83 89 97 101 103 107 109 113 127 131 137 139 149 151 157 163 167 173 179 181 191 193 197 199 211 223 227 229 233 239 241 251 257";
       roots = "0 0 0 3 2 2 3 2 5 2 3 2 6 3 5 2 2 2 2 7 5 3 2 3 5 2 5 2 6 3 3 2 3 2 2 6 5 2 5 2 2 2 19 5 2 3 2 3 2 6 3 7 7 6 3";
-    
+
       //Determine R
       if ((K>=40) && (K<=159)) {
 	R = 5;
@@ -612,7 +609,7 @@ namespace itpp {
       } else {
 	R = 20;
       }
-    
+
       //Determine C
       if ((K>=481)&&(K<=530)) {
 	p = 53;
@@ -638,16 +635,16 @@ namespace itpp {
 	  C = p+1;
 	}
       }
-    
+
       //Construct the base sequencs s for intra-row permutaions
       s.set_size(p-1,false);
       s.clear();
       s(0) = 1;
       for (i=1; i<=(p-2); i++) {
-	s(i) = (int) mod((long) (v * s(i-1)), (long) p);
+	s(i) = mod(v * s(i-1), p);
       }
-    
-      //Let q(0) = 1 be the first prime integer in {q(j)}, and select the consecutive 
+
+      //Let q(0) = 1 be the first prime integer in {q(j)}, and select the consecutive
       //minimum prime integers {q(j)}, j = 1, 2, ..., (R-1) such that gcd( q(j), p-1) == 1, q(j) > 6, and q(j) > q(j-1)
       q.set_size(R, false);
       q.clear();
@@ -656,20 +653,20 @@ namespace itpp {
 	for (i=0; i<primes.length(); i++) {
 	  qj = primes(i);
 	  if ( (qj>6) && (qj>q(j-1)) ) {
-	    if (gcd((long) qj,(long) (p-1)) == 1) {
+	    if (gcd(qj, p-1) == 1) {
 	      q(j) = qj;
 	      break;
 	    }
 	  }
 	}
       }
-    
+
       //Definitions of Pat1, Pat2, Pat3, and Pat4:
       Pat1 = "19 9 14 4 0 2 5 7 12 18 10 8 13 17 3 1 16 6 15 11";
       Pat2 = "19 9 14 4 0 2 5 7 12 18 16 13 17 15 3 1 6 11 8 10";
       Pat3 = "9 8 7 6 5 4 3 2 1 0";
       Pat4 = "4 3 2 1 0";
-    
+
       //T(j) is the inter-row permutation patters defined as one of the following four
       //kinds of patterns: Pat1, Pat2, Pat3, and Pat4 depending on the number of input bits K
       if (K>=3211) {
@@ -691,7 +688,7 @@ namespace itpp {
       } else {
 	T = Pat4;
       }
-    
+
       //Permute {q(j)} to make {r(j)} such that r(T(j)) = q(j), j = 0, 1, ..., (R-1),
       //where T(j) indicates the original row position of the j-th permuted row
       r.set_size(R,false);
@@ -699,22 +696,22 @@ namespace itpp {
       for (j=0; j<=(R-1); j++) {
 	r( T(j) ) = q(j);
       }
-    
+
       //U(j,i) is the input bit position of i-th output after the permutation of j-th row
       //Perform the j-th (j=0, 1, 2, ..., (R-1)) intra-row permutation as
       U.set_size(R,C,false);
       U.clear();
-      if (C==p) {    
+      if (C==p) {
 	for (j=0; j<=(R-1); j++) {
 	  for (i=0; i<=(p-2); i++) {
-	    U(j,i) = s( mod((long) (i*r(j)), (long) (p-1)) );
+	    U(j,i) = s(mod(i*r(j), p-1));
 	  }
 	  U(j,p-1) = 0;
 	}
       } else if (C==(p+1)) {
 	for (j=0; j<=(R-1); j++) {
 	  for (i=0; i<=(p-2); i++) {
-	    U(j,i) = s( mod((long) (i*r(j)),(long) (p-1)) ); 
+	    U(j,i) = s(mod(i*r(j), p-1));
 	  }
 	  U(j,p-1) = 0;
 	  U(j,p) = p;
@@ -727,11 +724,11 @@ namespace itpp {
       } else if (C==(p-1)) {
 	for (j=0; j<=(R-1); j++) {
 	  for (i=0; i<=(p-2); i++) {
-	    U(j,i) = s( mod((long) (i*r(j)),(long) (p-1)) ) - 1;
+	    U(j,i) = s(mod(i*r(j), p-1)) - 1;
 	  }
 	}
       }
-    
+
       //Calculate the interleaver sequence:
       I.set_size(K, false);
       I.clear();
@@ -747,8 +744,8 @@ namespace itpp {
 	  }
 	}
       }
-    
-      return I;    
+
+      return I;
     }
   }
 
