@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Conversion routines between IT++ and Matlab
  * \author Tony Ottosson and Pal Frenger
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -43,7 +40,7 @@ namespace itpp {
   // mex -> it++
   //--------------------------------------------------------
 
-  /*! 
+  /*!
     \addtogroup mexfiles
     \brief Conversions between IT++ and Matlab for writing mex-files.
     \author Tony Ottosson and Pal Frenger
@@ -53,8 +50,10 @@ namespace itpp {
     A simple mex-file that performs QPSK modulation is given below.
 
     \code
-    #include <itcomm.h>
-    #include <itmex.h>
+    #include <itpp/itcomm.h>
+    #include <itpp/itmex.h>
+
+    using namespace itpp;
 
     void mexFunction(int n_output, mxArray *output[], int n_input, const mxArray *input[])
     {
@@ -64,10 +63,10 @@ namespace itpp {
 
     // Convert input variables to IT++ format
     bvec input_bits = mxArray2bvec(input[0]);
-    
+
     // ------------------ Start of routine ---------------------------
     cvec output_symbols;
-    QPSK_45 qpsk;
+    QPSK qpsk;
 
     output_symbols = qpsk.modulate_bits(input_bits);
     // ------------------ End of routine -----------------------------
@@ -81,8 +80,10 @@ namespace itpp {
     \endcode
   */
 
-  //!\addtogroup mexfiles
-  //!@{
+  /*!
+   * \addtogroup mexfiles
+   * @{
+   */
 
   // --------------------------------------------------------
   // mex -> IT++
@@ -98,7 +99,8 @@ namespace itpp {
   double mxArray2double(const mxArray *in);
   //! Convert the matlab-format mxArray to complex<double>
   std::complex<double> mxArray2double_complex(const mxArray *in);
-  //string mxArray2string(const mxArray *in);
+  //! Convert the matlab-format mxArray to string
+  std::string mxArray2string(const mxArray *in);
 
   //! Convert the matlab-format mxArray to bvec
   bvec mxArray2bvec(const mxArray *in);
@@ -136,7 +138,8 @@ namespace itpp {
   void double2mxArray(const double &in, mxArray *out);
   //! Convert complex<double> to the matlab-format mxArray
   void double_complex2mxArray(const std::complex<double> &in, mxArray *out);
-  //void string2mxArray(const string &in, mxArray *out);
+  //! Convert string to the matlab-format mxArray
+  void string2mxArray(const std::string &in, mxArray* &out);
 
   //! Convert bvec to the matlab-format mxArray
   void bvec2mxArray(const bvec &in, mxArray *out);
@@ -204,7 +207,9 @@ namespace itpp {
   //! Convert C-format pointer to pointer to double (real and imaginary parts) to matlab-format mxArray
   void Ccmat2mxArray(double **in_real, double **in_imag, mxArray *out);
 
-  //!@}
+  /*!
+   * @}
+   */
 
 
   bin mxArray2bin(const mxArray *in)
@@ -272,6 +277,16 @@ namespace itpp {
 
   }
 
+  std::string mxArray2string(const mxArray *in)
+  {
+    if (in == 0)
+      mexErrMsgTxt("mxArray2string: Pointer to data is NULL");
+    std::string str = mxArrayToString(in);
+    if (str.data() == 0)
+      mexErrMsgTxt("mxArray2string: Could not convert mxArray to string");
+    return str;
+  }
+
   bvec mxArray2bvec(const mxArray *in)
   {
     bvec out;
@@ -305,7 +320,7 @@ namespace itpp {
     out.set_size(size,false);
 
     for (i=0; i<size; i++) {
-      out(i) = (short) (*temp++);    
+      out(i) = (short) (*temp++);
     }
 
     return out;
@@ -325,7 +340,7 @@ namespace itpp {
     out.set_size(size,false);
 
     for (i=0; i<size; i++) {
-      out(i) = (int) (*temp++);    
+      out(i) = (int) (*temp++);
     }
 
     return out;
@@ -345,7 +360,7 @@ namespace itpp {
     out.set_size(size,false);
 
     for (i=0; i<size; i++) {
-      out(i) = (*temp++);    
+      out(i) = (*temp++);
     }
 
     return out;
@@ -418,7 +433,7 @@ namespace itpp {
 
     for (c=0; c<cols; c++) {
       for (r=0; r<rows; r++) {
-	out(r,c) = (short) (*temp++);    
+	out(r,c) = (short) (*temp++);
       }
     }
 
@@ -441,7 +456,7 @@ namespace itpp {
 
     for (c=0; c<cols; c++) {
       for (r=0; r<rows; r++) {
-	out(r,c) = (int) (*temp++);    
+	out(r,c) = (int) (*temp++);
       }
     }
 
@@ -464,7 +479,7 @@ namespace itpp {
 
     for (c=0; c<cols; c++) {
       for (r=0; r<rows; r++) {
-	out(r,c) = (*temp++);    
+	out(r,c) = (*temp++);
       }
     }
 
@@ -498,26 +513,35 @@ namespace itpp {
     return out;
 
   }
-  
+
   void double2mxArray(const double &in, mxArray *out)
-  { 
+  {
     double* temp = (double *) mxGetPr(out);
     if (temp==0) mexErrMsgTxt("double2mxArray: Pointer to data is NULL");
 
     *temp= (double) in;
   }
-  
+
   void double_complex2mxArray(const std::complex<double> &in, mxArray *out)
   {
     double* tempR = (double *) mxGetPr(out);
     double* tempI = (double *) mxGetPi(out);
     if (tempR==0) mexErrMsgTxt("double_complex2mxArray: Pointer to real valued part is NULL");
     if (tempI==0) mexErrMsgTxt("double_complex2mxArray: Pointer to imaginary valued part is NULL");
-    
+
     *tempR= (double) in.real();
     *tempI= (double) in.imag();
   }
 
+  void string2mxArray(const std::string &in, mxArray* &out)
+  {
+    if (in.data() == 0)
+      mexErrMsgTxt("string2mxArray: Pointer to string is NULL");
+    out = mxCreateString(in.data());
+    if (out == 0)
+      mexErrMsgTxt("string2mxArray: Could not convert string to mxArray");
+  }
+
   void bvec2mxArray(const bvec &in, mxArray *out)
   {
     double* temp = (double *) mxGetPr(out);
@@ -584,7 +608,7 @@ namespace itpp {
 	if(in(r,c))
 	  *temp++= 1.0;
 	else
-	  *temp++= 0.0;    
+	  *temp++= 0.0;
       }
     }
 
@@ -722,7 +746,7 @@ namespace itpp {
     if (cols==0) mexErrMsgTxt("mxArray2Csmat: Data has zero columns");
     for (c=0; c<cols; c++) {
       for (r=0; r<rows; r++) {
-	out[r][c] = (short) (*temp++);    
+	out[r][c] = (short) (*temp++);
       }
     }
   }
@@ -738,7 +762,7 @@ namespace itpp {
     if (cols==0) mexErrMsgTxt("mxArray2Cimat: Data has zero columns");
     for (c=0; c<cols; c++) {
       for (r=0; r<rows; r++) {
-	out[r][c] = (int) (*temp++);    
+	out[r][c] = (int) (*temp++);
       }
     }
   }
@@ -754,7 +778,7 @@ namespace itpp {
     if (cols==0) mexErrMsgTxt("mxArray2Cmat: Data has zero columns");
     for (c=0; c<cols; c++) {
       for (r=0; r<rows; r++) {
-	out[r][c] = (*temp++);    
+	out[r][c] = (*temp++);
       }
     }
   }
@@ -772,8 +796,8 @@ namespace itpp {
     if (cols==0) mexErrMsgTxt("mxArray2Cmat: Data has zero columns");
     for (c=0; c<cols; c++) {
       for (r=0; r<rows; r++) {
-	out_real[r][c] = (*tempR++);    
-	out_imag[r][c] = (*tempI++);    
+	out_real[r][c] = (*tempR++);
+	out_imag[r][c] = (*tempI++);
       }
     }
   }
