@@ -1,11 +1,8 @@
 /*!
- * \file 
- * \brief Include file for the IT++ source coding library
+ * \file
+ * \brief Include file for the IT++ source coding module
  * \author Tony Ottosson
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -33,12 +30,25 @@
 #ifndef ITSRCCODE_H
 #define ITSRCCODE_H
 
-#include <itpp/itbase.h>
+/*!
+ * \defgroup srccode Source Coding Module
+ * @{
+ */
 
-#include <itpp/srccode/vq.h>
-#include <itpp/srccode/vqtrain.h>
+//! \defgroup audio Audio
+//! \defgroup image Image Functions and Classes
+//! \defgroup lpc LPC-related Functions
+//! \defgroup sourcecoding Source Coding Routines
+
+/*!
+ * @}
+ */
+
+#include <itpp/itsignal.h>
+#include <itpp/srccode/audiofile.h>
 #include <itpp/srccode/gmm.h>
 #include <itpp/srccode/lpcfunc.h>
-#include <itpp/srccode/audiofile.h>
+#include <itpp/srccode/vq.h>
+#include <itpp/srccode/vqtrain.h>
 
 #endif // #ifndef ITSRCCODE_H
