@@ -1,11 +1,8 @@
 /*!
- * \file 
+ * \file
  * \brief Implementation of a vector quantizer class (unconstrained)
  * \author Thomas Eriksson
  *
- * $Date$
- * $Revision$
- *
  * -------------------------------------------------------------------------
  *
  * IT++ - C++ library of mathematical, signal processing, speech processing,
@@ -37,6 +34,7 @@
 #include <iostream>
 #include <cstdlib>
 
+//! \cond
 
 using std::ifstream;
 using std::ofstream;
@@ -104,7 +102,7 @@ ivec Vector_Quantizer::encode(const vec &x, int num)
 			S+=a*a;
 			if (S>=MinS[num-1]) goto sune;
 		}
-		for (index=num-2;(index>=0) && (S<MinS[index]);index--); 
+		for (index=num-2;(index>=0) && (S<MinS[index]);index--);
 		for (j=MinS.length()-2;j>index;j--) {
 			MinS[j+1]=MinS[j];// memcpy, memmov
 			MinIndex[j+1]=MinIndex[j];
@@ -128,8 +126,6 @@ Array<vec> Vector_Quantizer::decode(const ivec &Index) const
 }
 
 
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-
 ifstream &operator>>( ifstream &ifs, vec &v)
 {
 	int    i;
@@ -173,7 +169,6 @@ ifstream &operator>>( ifstream &ifs, vec &v)
 	return ifs;
 }
 
-#endif //DOXYGEN_SHOULD_SKIP_THIS
 
 void Vector_Quantizer::load(const char *Name)
 {
@@ -224,7 +219,7 @@ void Vector_Quantizer::modify_codevector(int no, double mul, const vec &add)
 	for (int i=0;i<Dim;i++) {
 		CodeBook._elem(pos+i)*=mul;
 		CodeBook._elem(pos+i)+=add[i];
-	}	
+	}
 }
 
 vec Vector_Quantizer::get_codevector(int Index) const
@@ -348,3 +343,5 @@ ivec scalar_encode(vec &x, vec &Levels)
 }
 
 } // namespace itpp
+
+//! \endcond
